var searchData=
[
  ['c_5fpl_5fsetcontlabelformat',['c_pl_setcontlabelformat',['../plcont_8c.html#afa622f7f9cfbdbf1622e15f189d6adf7',1,'c_pl_setcontlabelformat():&#160;plcont.c'],['../namespaceplplot.html#aee71f42f3dd91fbd4c3023d5cbbb76c9',1,'plplot::c_pl_setcontlabelformat()'],['../plplot_8h.html#ab92ad7ccd9f1667f27dbc4a9d07f8864',1,'c_pl_setcontlabelformat():&#160;plcont.c']]],
  ['c_5fpl_5fsetcontlabelparam',['c_pl_setcontlabelparam',['../plcont_8c.html#a4249895b4fa5e55e14e659acb68e0d90',1,'c_pl_setcontlabelparam():&#160;plcont.c'],['../namespaceplplot.html#adae9a44f32a118485bd1e3c93672991b',1,'plplot::c_pl_setcontlabelparam()'],['../plplot_8h.html#a487a1e2265297e29a1538db001744f83',1,'c_pl_setcontlabelparam():&#160;plcont.c']]],
  ['c_5fpladv',['c_pladv',['../plpage_8c.html#af62c8a54a3adbe53682feaefc84207d4',1,'c_pladv():&#160;plpage.c'],['../namespaceplplot.html#ac80a8680ccea0eb4bca9610e51e2890d',1,'plplot::c_pladv()'],['../plplot_8h.html#a8a327be272177954338a43a173a8fdb5',1,'c_pladv():&#160;plpage.c']]],
  ['c_5fplarc',['c_plarc',['../plarc_8c.html#a982488b8820209d5c2767b8ddadef259',1,'c_plarc():&#160;plarc.c'],['../namespaceplplot.html#a087e8e9e88f4dfeda75e247d8427c078',1,'plplot::c_plarc()'],['../plplot_8h.html#aa4edd532f3768f7d88bf4643e448d203',1,'c_plarc():&#160;plarc.c']]],
  ['c_5fplaxes',['c_plaxes',['../plbox_8c.html#ae060810739107db0d1317a4e6516ed8d',1,'c_plaxes():&#160;plbox.c'],['../namespaceplplot.html#a5a2294470fad82d8d1903ef7ab2f039b',1,'plplot::c_plaxes()'],['../plplot_8h.html#a8d985a901ee2b4dd3319ecef684398f6',1,'c_plaxes():&#160;plbox.c']]],
  ['c_5fplbin',['c_plbin',['../plhist_8c.html#ada946ac0cd91bbc21ef6d1804ff0b413',1,'c_plbin():&#160;plhist.c'],['../namespaceplplot.html#a1cffa6aacb8418d7d04264d0efe3ac9a',1,'plplot::c_plbin()'],['../plplot_8h.html#a589a2ad1201ccedc14ff36a92689c9f3',1,'c_plbin():&#160;plhist.c']]],
  ['c_5fplbop',['c_plbop',['../plpage_8c.html#a367e05b88a41c3698fd8fbf18e936814',1,'c_plbop():&#160;plpage.c'],['../namespaceplplot.html#a24ef1d23f50b90b5e2c7713ff23011bd',1,'plplot::c_plbop()'],['../plplot_8h.html#accdeaeb65542509d2b8f827266b54982',1,'c_plbop():&#160;plpage.c']]],
  ['c_5fplbox',['c_plbox',['../plbox_8c.html#a8baa2482beabc8f507abefe99e1f853d',1,'c_plbox():&#160;plbox.c'],['../namespaceplplot.html#ac8b56eeae94e3a31bce84319403f5c05',1,'plplot::c_plbox()'],['../plplot_8h.html#a1d345aa0791565ca6ffcf3ea23355474',1,'c_plbox():&#160;plbox.c']]],
  ['c_5fplbox3',['c_plbox3',['../plbox_8c.html#aad670fce5bbc81761ea652ac72a49400',1,'c_plbox3():&#160;plbox.c'],['../namespaceplplot.html#af6474cc7276a3eeb18daac8b85a9dce7',1,'plplot::c_plbox3()'],['../plplot_8h.html#a0da7c3be9cd6853133c2676d1b987042',1,'c_plbox3():&#160;plbox.c']]],
  ['c_5fplbtime',['c_plbtime',['../pltime_8c.html#a151ee2d1ffd36209a04c859774c4dca3',1,'c_plbtime():&#160;pltime.c'],['../namespaceplplot.html#a3645feff751dc481df03309fe050608d',1,'plplot::c_plbtime()'],['../plplot_8h.html#a08d30a801c0153367b9913e5ec64b04d',1,'c_plbtime():&#160;plplot.h']]],
  ['c_5fplcalc_5fworld',['c_plcalc_world',['../plpage_8c.html#a6804c5fe0386757e4dd30e57128cb286',1,'c_plcalc_world():&#160;plpage.c'],['../namespaceplplot.html#a633ae2dc8fb0945218d5649ac97c57c7',1,'plplot::c_plcalc_world()'],['../plplot_8h.html#a25d48293a603d07e811c04b9477faf94',1,'c_plcalc_world():&#160;plplot.h']]],
  ['c_5fplclear',['c_plclear',['../plpage_8c.html#ad33b8a29e791c9996234eacfd48d0f2f',1,'c_plclear():&#160;plpage.c'],['../namespaceplplot.html#a6920227b7c3151c32e23a019a38e6e4a',1,'plplot::c_plclear()'],['../plplot_8h.html#a91c77a69b1de6d6dea80a8b57f1c3292',1,'c_plclear():&#160;plpage.c']]],
  ['c_5fplcol0',['c_plcol0',['../plctrl_8c.html#a2584e744f6544b0160c4dcbba0d048a3',1,'c_plcol0():&#160;plctrl.c'],['../namespaceplplot.html#a3e28fda9a95dc8b2fa32d83fcc87d171',1,'plplot::c_plcol0()'],['../plplot_8h.html#a56f6ef6a76c18a7b7b9d2c891d1467be',1,'c_plcol0():&#160;plctrl.c']]],
  ['c_5fplcol1',['c_plcol1',['../plctrl_8c.html#a603b23649a648f93bc71a72c74e7b322',1,'c_plcol1():&#160;plctrl.c'],['../namespaceplplot.html#a3623f4f7d266155f40cacc03ee9c7942',1,'plplot::c_plcol1()'],['../plplot_8h.html#a5ada6ff695ce184c11be47def6dae0a6',1,'c_plcol1():&#160;plctrl.c']]],
  ['c_5fplcolorbar',['c_plcolorbar',['../pllegend_8c.html#acab91e12a21610cf82acb45af785eef8',1,'c_plcolorbar():&#160;pllegend.c'],['../namespaceplplot.html#a4964a6240e828bb7b8eaa1f1ec7805c3',1,'plplot::c_plcolorbar()'],['../plplot_8h.html#a46c03ffbe85b2a03a5f8597188e0e488',1,'c_plcolorbar():&#160;plplot.h']]],
  ['c_5fplconfigtime',['c_plconfigtime',['../pltime_8c.html#a00537880dbb29517076b2fc924df4005',1,'c_plconfigtime():&#160;pltime.c'],['../namespaceplplot.html#affd4a9742097665110b2cdc8732207f0',1,'plplot::c_plconfigtime()'],['../plplot_8h.html#a5f35b5400d68ae1ebe6418c5bec5052c',1,'c_plconfigtime():&#160;pltime.c']]],
  ['c_5fplcont',['c_plcont',['../plcont_8c.html#a523561cdd668576f34cc4286422495f3',1,'c_plcont():&#160;plcont.c'],['../namespaceplplot.html#ae4f6b3c11f651d6103168853fdf8eec1',1,'plplot::c_plcont()'],['../plplot_8h.html#a9ee068257e863261b9da62455e3e6467',1,'c_plcont():&#160;plcont.c']]],
  ['c_5fplcpstrm',['c_plcpstrm',['../plcore_8c.html#a808e7856a0bef6d71c2309abea207c78',1,'c_plcpstrm():&#160;plcore.c'],['../namespaceplplot.html#a695e1e6c1def7151027bb5478dc74649',1,'plplot::c_plcpstrm()'],['../plplot_8h.html#ad16c39cffa39e594adba42654a95b698',1,'c_plcpstrm():&#160;plcore.c']]],
  ['c_5fplctime',['c_plctime',['../pltime_8c.html#abfd974ab4f78f7b591e73cfc3b3f4f4c',1,'c_plctime():&#160;pltime.c'],['../namespaceplplot.html#a8ea62d1294f79d32b7b7d8a31a4a602b',1,'plplot::c_plctime()'],['../plplot_8h.html#afc0c95bf532e98f61c0da1e8933bf6f6',1,'c_plctime():&#160;plplot.h']]],
  ['c_5fplend',['c_plend',['../plcore_8c.html#a057806120a84ea1da3ffef67bff47491',1,'c_plend():&#160;plcore.c'],['../namespaceplplot.html#abc2df3677e61a8fad26cedd5b51a2048',1,'plplot::c_plend()'],['../plplot_8h.html#a4ab1fe008a7495add8bb292f79806ead',1,'c_plend():&#160;plcore.c']]],
  ['c_5fplend1',['c_plend1',['../plcore_8c.html#a82d7eca932a870b8724abf64609be0ce',1,'c_plend1():&#160;plcore.c'],['../namespaceplplot.html#acf191144197c70cba08a5ba074ee2b01',1,'plplot::c_plend1()'],['../plplot_8h.html#a1a5146bbedba53c0ce7fd661d0424f61',1,'c_plend1():&#160;plcore.c']]],
  ['c_5fplenv',['c_plenv',['../plvpor_8c.html#a7e461d8a90e62da9e029a716b2a65f7a',1,'c_plenv():&#160;plvpor.c'],['../namespaceplplot.html#aa5a49c269c021e95fc9fcb931bce884a',1,'plplot::c_plenv()'],['../plplot_8h.html#a23b6e27e49270223a087483456992753',1,'c_plenv():&#160;plvpor.c']]],
  ['c_5fplenv0',['c_plenv0',['../plvpor_8c.html#a89b403787b4a6f2bb94b0f0f5caf5524',1,'c_plenv0():&#160;plvpor.c'],['../namespaceplplot.html#a0dec50f8df8650e5c63240732c5c139f',1,'plplot::c_plenv0()'],['../plplot_8h.html#adb576c92128ae8b6b031c12ac15a5e1b',1,'c_plenv0():&#160;plvpor.c']]],
  ['c_5fplenvi',['c_plenvi',['../plvpor_8c.html#a55f06d263988e22e53577fe12ddfdf27',1,'plvpor.c']]],
  ['c_5fpleop',['c_pleop',['../plpage_8c.html#aad0b2b0b4164d2859b49c23e9564dd5c',1,'c_pleop():&#160;plpage.c'],['../namespaceplplot.html#a775da376e7d176f78612b9f7fd1cc83a',1,'plplot::c_pleop()'],['../plplot_8h.html#a8859fcac8c131dfc61b767b13540387d',1,'c_pleop():&#160;plpage.c']]],
  ['c_5fplerrx',['c_plerrx',['../pltick_8c.html#a5404a648c7154be3f6e87322739cd3cf',1,'c_plerrx():&#160;pltick.c'],['../namespaceplplot.html#ac076ac0b43273f5b03bb1dfd119520c6',1,'plplot::c_plerrx()'],['../plplot_8h.html#a89c4133449bd7b2d4998bcae6a04c698',1,'c_plerrx():&#160;pltick.c']]],
  ['c_5fplerry',['c_plerry',['../pltick_8c.html#a51350f520cc49d2678a4032af7e66a06',1,'c_plerry():&#160;pltick.c'],['../namespaceplplot.html#ad07526bf32f693dd555bb130fea6cb08',1,'plplot::c_plerry()'],['../plplot_8h.html#ab363162751ee6ef6e21d77ce54874af9',1,'c_plerry():&#160;pltick.c']]],
  ['c_5fplfamadv',['c_plfamadv',['../plcore_8c.html#ad03888fe21e744719a5215b2f71b0516',1,'c_plfamadv():&#160;plcore.c'],['../namespaceplplot.html#a16d0387c29f7b55f2f715eda38ddef08',1,'plplot::c_plfamadv()'],['../plplot_8h.html#a02ad120a9efe2cb42033f3a3f4aa1ce9',1,'c_plfamadv():&#160;plcore.c']]],
  ['c_5fplfill',['c_plfill',['../plfill_8c.html#add122d8446abf507f9c52441b3187507',1,'c_plfill():&#160;plfill.c'],['../namespaceplplot.html#a29dcedcfe602ab89eb6c7c39bd3a13d4',1,'plplot::c_plfill()'],['../plplot_8h.html#a44ab2b3b469771116a4db95b2e5fd27c',1,'c_plfill():&#160;plfill.c']]],
  ['c_5fplfill3',['c_plfill3',['../plfill_8c.html#a2ae5006ed491f176b41388fb63ef0ed7',1,'c_plfill3():&#160;plfill.c'],['../namespaceplplot.html#a9922ad7f71ded2e05ecac737560553c9',1,'plplot::c_plfill3()'],['../plplot_8h.html#a702dd1b227e02ca5d812cadf8cdfcfb1',1,'c_plfill3():&#160;plfill.c']]],
  ['c_5fplflush',['c_plflush',['../plcore_8c.html#aa68be25daff0516a7e2a0fac0bdfdd9a',1,'c_plflush():&#160;plcore.c'],['../namespaceplplot.html#a40447516f265e81a351fea707c9d2014',1,'plplot::c_plflush()'],['../plplot_8h.html#a97beafec282968a52d99a75b93accc29',1,'c_plflush():&#160;plcore.c']]],
  ['c_5fplfont',['c_plfont',['../plsym_8c.html#a40a75b5ed8da3806540634760754d005',1,'c_plfont():&#160;plsym.c'],['../namespaceplplot.html#a4c8504acd90d57225605b3100b9ae6a2',1,'plplot::c_plfont()'],['../plplot_8h.html#ab314b1eb2abdc661c87b988cf1862a88',1,'c_plfont():&#160;plsym.c']]],
  ['c_5fplfontld',['c_plfontld',['../plcore_8c.html#adca30e3b9bfef3b0ac9bcb394e15552c',1,'c_plfontld():&#160;plcore.c'],['../namespaceplplot.html#a36abac35d8a123b9355536166cd4d2be',1,'plplot::c_plfontld()'],['../plplot_8h.html#ab1801dd8db40f4262d7265a15710d987',1,'c_plfontld():&#160;plcore.c']]],
  ['c_5fplgchr',['c_plgchr',['../plcore_8c.html#a63e2da015640c52a9999c55342b646fc',1,'c_plgchr():&#160;plcore.c'],['../namespaceplplot.html#ace3a0eb9e18aab432711eb51ed647f8d',1,'plplot::c_plgchr()'],['../plplot_8h.html#aa34129723151f735bccb7235100d25f7',1,'c_plgchr():&#160;plplot.h']]],
  ['c_5fplgcmap1_5frange',['c_plgcmap1_range',['../plctrl_8c.html#a05c92a3d400885b6687b30db6d0ce659',1,'c_plgcmap1_range():&#160;plctrl.c'],['../namespaceplplot.html#aec44f4ef3d50f1dc278adae11964326b',1,'plplot::c_plgcmap1_range()'],['../plplot_8h.html#a97756af8171ea76ebc95c0fe747f0bf0',1,'c_plgcmap1_range():&#160;plplot.h']]],
  ['c_5fplgcol0',['c_plgcol0',['../plctrl_8c.html#a2204fa9527cb5b892dfdcadba29c6761',1,'c_plgcol0():&#160;plctrl.c'],['../namespaceplplot.html#acdf17d7691d47a3d8a68d433bd5d80fd',1,'plplot::c_plgcol0()'],['../plplot_8h.html#a29d0b83353fd7e9f5e428671755e5213',1,'c_plgcol0():&#160;plplot.h']]],
  ['c_5fplgcol0a',['c_plgcol0a',['../plctrl_8c.html#a8d7995b55fe427f40e992bacc226860a',1,'c_plgcol0a():&#160;plctrl.c'],['../namespaceplplot.html#a99ecf15dce209e6c20809005ae6347ff',1,'plplot::c_plgcol0a()'],['../plplot_8h.html#af98e10d22b67d3ba93d3ec2f243aa4a3',1,'c_plgcol0a():&#160;plplot.h']]],
  ['c_5fplgcolbg',['c_plgcolbg',['../plctrl_8c.html#af82d44c948a764dd378e6ae2525e8eff',1,'c_plgcolbg():&#160;plctrl.c'],['../namespaceplplot.html#af579d375a633a82a1640520f80bbefc5',1,'plplot::c_plgcolbg()'],['../plplot_8h.html#a3a708627395ec9e605b856d681ce10f8',1,'c_plgcolbg():&#160;plplot.h']]],
  ['c_5fplgcolbga',['c_plgcolbga',['../plctrl_8c.html#a04543ade16f2c09d0f44fd2d4893d9fd',1,'c_plgcolbga():&#160;plctrl.c'],['../namespaceplplot.html#a13b9989b5d67feed9f7ee409e3caf95c',1,'plplot::c_plgcolbga()'],['../plplot_8h.html#ae4759b661af4b185e35bf92749bab3e5',1,'c_plgcolbga():&#160;plplot.h']]],
  ['c_5fplgcompression',['c_plgcompression',['../plcore_8c.html#a9b95f1be421f4ffb0ecdd690acc51991',1,'c_plgcompression():&#160;plcore.c'],['../namespaceplplot.html#a958408ea497528c844fcd342d2a6e62a',1,'plplot::c_plgcompression()'],['../plplot_8h.html#abfc3c648a0b567d4f559c91881df9dcd',1,'c_plgcompression():&#160;plplot.h']]],
  ['c_5fplgdev',['c_plgdev',['../plcore_8c.html#a730e264140174728e5a9370500dd98b9',1,'c_plgdev():&#160;plcore.c'],['../namespaceplplot.html#ab4f16c8d829f988f7224946f97f1a503',1,'plplot::c_plgdev()'],['../plplot_8h.html#ac0a6d5bc5326bc6701c7d7eb84dd19ff',1,'c_plgdev():&#160;plcore.c']]],
  ['c_5fplgdidev',['c_plgdidev',['../plcore_8c.html#a148607d52aba56ef94c79a572e72749c',1,'c_plgdidev():&#160;plcore.c'],['../namespaceplplot.html#a08b05da624e55989128a0b5a6c030158',1,'plplot::c_plgdidev()'],['../plplot_8h.html#a6ceac24eef18fd53571f0dec736d365d',1,'c_plgdidev():&#160;plplot.h']]],
  ['c_5fplgdiori',['c_plgdiori',['../plcore_8c.html#af7d3028d40a2a370eaf59b252e70129d',1,'c_plgdiori():&#160;plcore.c'],['../namespaceplplot.html#a1c89b39dbbfc1e0ff0a1d69ab32ed18a',1,'plplot::c_plgdiori()'],['../plplot_8h.html#a8fa675f7f6fa7d2bb18948a007ec19d7',1,'c_plgdiori():&#160;plplot.h']]],
  ['c_5fplgdiplt',['c_plgdiplt',['../plcore_8c.html#ab7394daabcb9894bf7805308428c71e6',1,'c_plgdiplt():&#160;plcore.c'],['../namespaceplplot.html#aa3aed6fec8adb654a82ed2f76e5b62c0',1,'plplot::c_plgdiplt()'],['../plplot_8h.html#a857b0f6c556e29af73291eb0f5e5294d',1,'c_plgdiplt():&#160;plplot.h']]],
  ['c_5fplgdrawmode',['c_plgdrawmode',['../plctrl_8c.html#a24c49c2d4e1e478389980594527e5ab7',1,'c_plgdrawmode(void):&#160;plctrl.c'],['../plplot_8h.html#af320bdd8254937cf5f5fff6379e366ad',1,'c_plgdrawmode(void):&#160;plctrl.c']]],
  ['c_5fplgfam',['c_plgfam',['../plcore_8c.html#a7601ac2a53c8ee1385cace0dc8a17d8b',1,'c_plgfam():&#160;plcore.c'],['../namespaceplplot.html#aeaa6cb5cf62b5554b27ed0a558cc1419',1,'plplot::c_plgfam()'],['../plplot_8h.html#a2c79d5ca4664afe7cf69b6c571b649ea',1,'c_plgfam():&#160;plplot.h']]],
  ['c_5fplgfci',['c_plgfci',['../plcore_8c.html#a83276fc9443a12048337c947819acea3',1,'c_plgfci():&#160;plcore.c'],['../namespaceplplot.html#a940be8f28afc4213372e7028a49332dc',1,'plplot::c_plgfci()'],['../plplot_8h.html#ad34ded6547508ef7ef7b5cdb07bb74d3',1,'c_plgfci():&#160;plplot.h']]],
  ['c_5fplgfnam',['c_plgfnam',['../plcore_8c.html#a75a7c204e1e884ee546e0baf88917f54',1,'c_plgfnam():&#160;plcore.c'],['../namespaceplplot.html#a7abcf0815dc45adef4c8e9f6976457bb',1,'plplot::c_plgfnam()'],['../plplot_8h.html#a6423bbc4892a58f8cb4b8b630a6ac130',1,'c_plgfnam():&#160;plcore.c']]],
  ['c_5fplgfont',['c_plgfont',['../plsym_8c.html#a417eab946d23ab5c698a8bebb94b4f13',1,'c_plgfont():&#160;plsym.c'],['../namespaceplplot.html#a09d7ed095b889b350dfeea51e0643164',1,'plplot::c_plgfont()'],['../plplot_8h.html#af7a245bb044daa21faa18b0d4c014c2c',1,'c_plgfont():&#160;plplot.h']]],
  ['c_5fplglevel',['c_plglevel',['../plcore_8c.html#a0c11fe456b55f9f0062415101cb9dfc8',1,'c_plglevel():&#160;plcore.c'],['../namespaceplplot.html#a03f6f84ce00bddaf3a62753f102bbaee',1,'plplot::c_plglevel()'],['../plplot_8h.html#a0efd37df7fc5f5f2b5c0a8a8c1fb5baf',1,'c_plglevel():&#160;plplot.h']]],
  ['c_5fplgpage',['c_plgpage',['../plcore_8c.html#ad9555920fc7673920b6862e38d049191',1,'c_plgpage():&#160;plcore.c'],['../namespaceplplot.html#aead581d0f4d1ba49fea7f68cf637125c',1,'plplot::c_plgpage()'],['../plplot_8h.html#af02d7e496e73b1f705841448257d28e4',1,'c_plgpage():&#160;plplot.h']]],
  ['c_5fplgra',['c_plgra',['../plctrl_8c.html#afddf46dfe63168faf79c7ad0673c0bbb',1,'c_plgra():&#160;plctrl.c'],['../namespaceplplot.html#aba346d858ce4b8034c151817a6660250',1,'plplot::c_plgra()'],['../plplot_8h.html#a20f4029e24d5d3299dd3d2136afc572b',1,'c_plgra():&#160;plctrl.c']]],
  ['c_5fplgradient',['c_plgradient',['../plgradient_8c.html#a4a953d44f573a1b4f7dcb07118b42c5f',1,'c_plgradient():&#160;plgradient.c'],['../namespaceplplot.html#aafb18966be3797e86f37fedbaf494d1a',1,'plplot::c_plgradient()'],['../plplot_8h.html#a063367be3ffe4299a3ac8db371eb0fef',1,'c_plgradient():&#160;plgradient.c']]],
  ['c_5fplgriddata',['c_plgriddata',['../plgridd_8c.html#a679a2ae82f14e997a5d8d7ae2ba3df4b',1,'c_plgriddata():&#160;plgridd.c'],['../namespaceplplot.html#afea251801e6af259cc82f23648e306ef',1,'plplot::c_plgriddata()'],['../plplot_8h.html#a7aeb5aae19a7d81fb2b75b3bdbd469f2',1,'c_plgriddata():&#160;plplot.h']]],
  ['c_5fplgspa',['c_plgspa',['../plpage_8c.html#ac9d7c35262ab1c80cc1ed9bf15f7f128',1,'c_plgspa():&#160;plpage.c'],['../namespaceplplot.html#a4ce1c92abf1b0e8b03bb121d85a368c4',1,'plplot::c_plgspa()'],['../plplot_8h.html#afea94c13d8f0f4bd8b2153fa28f080b1',1,'c_plgspa():&#160;plplot.h']]],
  ['c_5fplgstrm',['c_plgstrm',['../plcore_8c.html#aa6ecda5740335b215a4c6ec05aefe2fc',1,'c_plgstrm():&#160;plcore.c'],['../namespaceplplot.html#afe7d7e80d20e74398048a49f90fe8543',1,'plplot::c_plgstrm()'],['../plplot_8h.html#a1d9430a0b423d181e06d67da386664aa',1,'c_plgstrm():&#160;plplot.h']]],
  ['c_5fplgver',['c_plgver',['../plcore_8c.html#a2f50780df4b008a23d5c881641bc4838',1,'c_plgver():&#160;plcore.c'],['../namespaceplplot.html#a4652222050781b78b00731923c12b25d',1,'plplot::c_plgver()'],['../plplot_8h.html#a4fe427e206890cdcae910c34a75c3794',1,'c_plgver():&#160;plcore.c']]],
  ['c_5fplgvpd',['c_plgvpd',['../plcore_8c.html#ae5b0ed045773267243e3c74dd6526ae6',1,'c_plgvpd():&#160;plcore.c'],['../namespaceplplot.html#a3533dd7926004f2257aef64b0b4782f9',1,'plplot::c_plgvpd()'],['../plplot_8h.html#a6b1c6e7fc2d4d988f94eba0ac2ca45e2',1,'c_plgvpd():&#160;plplot.h']]],
  ['c_5fplgvpw',['c_plgvpw',['../plcore_8c.html#a64c2cee6f05cffdd2bc9c8b85c94b662',1,'c_plgvpw():&#160;plcore.c'],['../namespaceplplot.html#aa790b07d902f8c09be09cba6b9c9e0ac',1,'plplot::c_plgvpw()'],['../plplot_8h.html#a64ef22b435f6d6bc21ef4552e6765b98',1,'c_plgvpw():&#160;plplot.h']]],
  ['c_5fplgxax',['c_plgxax',['../plcore_8c.html#a7e9b55b0ec2ae5525591f6fede113a9e',1,'c_plgxax():&#160;plcore.c'],['../namespaceplplot.html#ae2629ef40e532bd9856e5a63c8974b1d',1,'plplot::c_plgxax()'],['../plplot_8h.html#a62ad5fe400e5364017663feda6d4341d',1,'c_plgxax():&#160;plplot.h']]],
  ['c_5fplgyax',['c_plgyax',['../plcore_8c.html#ae147ba26e63df579fc9434c6c4cbc3cd',1,'c_plgyax():&#160;plcore.c'],['../namespaceplplot.html#a814bbaa498ccc04e9cf97a7cac4d86ef',1,'plplot::c_plgyax()'],['../plplot_8h.html#a949c1a3b75363b541294ebed21b0e26c',1,'c_plgyax():&#160;plplot.h']]],
  ['c_5fplgzax',['c_plgzax',['../plcore_8c.html#a720bd62d527c1db65f35b344c03140e9',1,'c_plgzax():&#160;plcore.c'],['../namespaceplplot.html#a0d09d91220c22c8d90eb8a4c94a2117f',1,'plplot::c_plgzax()'],['../plplot_8h.html#ab8b6270a88d9d8b737bf2dfac895cc04',1,'c_plgzax():&#160;plplot.h']]],
  ['c_5fplhist',['c_plhist',['../plhist_8c.html#a68d232788ff549df5301a47a5568eb82',1,'c_plhist():&#160;plhist.c'],['../namespaceplplot.html#aed4d8d7bc69de498a92b4c8f305e1ecc',1,'plplot::c_plhist()'],['../plplot_8h.html#a7b89fa38b97399d9dcd2758a47bcf906',1,'c_plhist():&#160;plhist.c']]],
  ['c_5fplhlsrgb',['c_plhlsrgb',['../plctrl_8c.html#afe5c216f6c83e64df5a16b48b2f7af15',1,'c_plhlsrgb():&#160;plctrl.c'],['../namespaceplplot.html#a9da5d6fa041c7256061955d7ace6e62a',1,'plplot::c_plhlsrgb()'],['../plplot_8h.html#a9e9560a0fddc381de37802b7d14ec1e1',1,'c_plhlsrgb():&#160;plplot.h']]],
  ['c_5fplimage',['c_plimage',['../plimage_8c.html#ae0d2aee9a1e865cda3428d51990ed46f',1,'c_plimage():&#160;plimage.c'],['../namespaceplplot.html#a6ca701d920c0c0708ad8685969baab6e',1,'plplot::c_plimage()'],['../plplot_8h.html#a8e4c28058e6347f092502d71de4537de',1,'c_plimage():&#160;plimage.c']]],
  ['c_5fplimagefr',['c_plimagefr',['../plimage_8c.html#a870571ff0cc72aa355cc64c68b94a316',1,'c_plimagefr():&#160;plimage.c'],['../namespaceplplot.html#a4b288976d5756013c9c41dcee6b48bc7',1,'plplot::c_plimagefr()'],['../plplot_8h.html#a7f5ce2feda00354aebbd4073db12c492',1,'c_plimagefr():&#160;plimage.c']]],
  ['c_5fplinit',['c_plinit',['../plcore_8c.html#ab4936c1ab86820efcc43ba6d2d3e98bd',1,'c_plinit():&#160;plcore.c'],['../namespaceplplot.html#af6879e026a87986cf246b6ad230f5d74',1,'plplot::c_plinit()'],['../plplot_8h.html#a16ca877b784c3f1afa2157e7b01c9f09',1,'c_plinit():&#160;plcore.c']]],
  ['c_5fpljoin',['c_pljoin',['../plline_8c.html#ac9265d404c0ac361ae7c052a72b05815',1,'c_pljoin():&#160;plline.c'],['../namespaceplplot.html#ac22b591e6252c2aaaa38d4f3bf847375',1,'plplot::c_pljoin()'],['../plplot_8h.html#ae41b66e619fb441dae94b8fe9c7de1e7',1,'c_pljoin():&#160;plline.c']]],
  ['c_5fpllab',['c_pllab',['../plsym_8c.html#a3f0cbf25fcf03518b5a816339b84f651',1,'c_pllab():&#160;plsym.c'],['../namespaceplplot.html#a49e321eebc6a6d803fc9b2e39bb783ec',1,'plplot::c_pllab()'],['../plplot_8h.html#a2d786426e8f623cbd69b2b2c214cb2c9',1,'c_pllab():&#160;plsym.c']]],
  ['c_5fpllegend',['c_pllegend',['../pllegend_8c.html#a81937dcc67070290675b8863db8ec01c',1,'c_pllegend():&#160;pllegend.c'],['../namespaceplplot.html#aec97625786c16fb8de98d167bc88f44d',1,'plplot::c_pllegend()'],['../plplot_8h.html#a981ec3dc0aa9b0f285d8547aea82d23d',1,'c_pllegend():&#160;plplot.h']]],
  ['c_5fpllightsource',['c_pllightsource',['../plot3d_8c.html#ae9ea6dcd1635da7195cb11048d8a934f',1,'c_pllightsource():&#160;plot3d.c'],['../namespaceplplot.html#a0ec91180b328295174279b595bff19d6',1,'plplot::c_pllightsource()'],['../plplot_8h.html#a64222d2e573b3f5e467cbbc55f16d3f6',1,'c_pllightsource():&#160;plot3d.c']]],
  ['c_5fplline',['c_plline',['../plline_8c.html#a26288c2e08cbaa8f6df2a8325e6e74fe',1,'c_plline():&#160;plline.c'],['../namespaceplplot.html#a64787a31239b0f65de85ba8f86cc090b',1,'plplot::c_plline()'],['../plplot_8h.html#a17c82e570f86b8f81c5542b786946da3',1,'c_plline():&#160;plline.c']]],
  ['c_5fplline3',['c_plline3',['../plline_8c.html#a286804d330435726d509e0d6d0c8e886',1,'c_plline3():&#160;plline.c'],['../namespaceplplot.html#ab692a525dff33d0983d85e80d156c27c',1,'plplot::c_plline3()'],['../plplot_8h.html#aaf02d5c98fddf91faab1b481e5de3686',1,'c_plline3():&#160;plline.c']]],
  ['c_5fpllsty',['c_pllsty',['../plsdef_8c.html#a3caba41d0d5222a480b34fd1586d4262',1,'c_pllsty():&#160;plsdef.c'],['../namespaceplplot.html#a618ea88b197ff40d2f4010eaeb9f0f1f',1,'plplot::c_pllsty()'],['../plplot_8h.html#a317c00e1dc4960ac3aa3181ffce231a6',1,'c_pllsty():&#160;plsdef.c']]],
  ['c_5fplmap',['c_plmap',['../namespaceplplot.html#abbed1f0ce5c63859cd965fb705f3b76b',1,'plplot::c_plmap()'],['../plplot_8h.html#ad62f515e45976081ce8a9f7bac1f5fbe',1,'c_plmap():&#160;plplot.h']]],
  ['c_5fplmapfill',['c_plmapfill',['../namespaceplplot.html#a6e8894d848e822253ae7c7be0288822d',1,'plplot::c_plmapfill()'],['../plplot_8h.html#a30c236fa79bdfa1660dd9f118943d837',1,'c_plmapfill():&#160;plplot.h']]],
  ['c_5fplmapline',['c_plmapline',['../namespaceplplot.html#a45dfd021cee74defcf179d3e2afb1279',1,'plplot::c_plmapline()'],['../plplot_8h.html#a43bd3bdada218a375a746473476ec81b',1,'c_plmapline():&#160;plplot.h']]],
  ['c_5fplmapstring',['c_plmapstring',['../namespaceplplot.html#a042a114f197ac7850ea6ddc47934609a',1,'plplot::c_plmapstring()'],['../plplot_8h.html#aa6f4fa0f8caa352ea1f189e0a5bc602b',1,'c_plmapstring():&#160;plplot.h']]],
  ['c_5fplmaptex',['c_plmaptex',['../namespaceplplot.html#a92bddec507cdd2028fee7b29a2637370',1,'plplot::c_plmaptex()'],['../plplot_8h.html#a82bfabf7d9063d7dd24b55c536102b33',1,'c_plmaptex():&#160;plplot.h']]],
  ['c_5fplmeridians',['c_plmeridians',['../namespaceplplot.html#a5a770471e77b39477f7c99630c37bd42',1,'plplot::c_plmeridians()'],['../plplot_8h.html#a03da9456b0d3e6e189495f2b7f07cd21',1,'c_plmeridians():&#160;plplot.h']]],
  ['c_5fplmesh',['c_plmesh',['../plot3d_8c.html#a83af10b5e13e675fde1ed02cb74275ce',1,'c_plmesh():&#160;plot3d.c'],['../namespaceplplot.html#adaf1e9a7519889676ffcced8e5f2931f',1,'plplot::c_plmesh()'],['../plplot_8h.html#a478ab14993898d98430ddff1ecb40e42',1,'c_plmesh():&#160;plot3d.c']]],
  ['c_5fplmeshc',['c_plmeshc',['../plot3d_8c.html#a4524e968a47e4ec721bd09e64f615b23',1,'c_plmeshc():&#160;plot3d.c'],['../namespaceplplot.html#aed89e08e72504dc67d86e6c73e2c9b62',1,'plplot::c_plmeshc()'],['../plplot_8h.html#a200a123ec2394a19f7f85041216670fb',1,'c_plmeshc():&#160;plot3d.c']]],
  ['c_5fplmkstrm',['c_plmkstrm',['../plcore_8c.html#ad60759694b61589b021ed95fe5299be7',1,'c_plmkstrm():&#160;plcore.c'],['../namespaceplplot.html#a163a6136396556c52433d6bd1b4342b4',1,'plplot::c_plmkstrm()'],['../plplot_8h.html#a4a61b2952989661dfeba25255e5b69cd',1,'c_plmkstrm():&#160;plplot.h']]],
  ['c_5fplmtex',['c_plmtex',['../plsym_8c.html#a510326bf12a0df57a118cdec925a1f88',1,'c_plmtex():&#160;plsym.c'],['../namespaceplplot.html#a57d79fb892b317251c8b6ebd2bc8597a',1,'plplot::c_plmtex()'],['../plplot_8h.html#a18af12e84fb7c6dfe48560934dd7dc95',1,'c_plmtex():&#160;plsym.c']]],
  ['c_5fplmtex3',['c_plmtex3',['../plsym_8c.html#a2aee6697d56f5e6469074d647e06a30c',1,'c_plmtex3():&#160;plsym.c'],['../namespaceplplot.html#a350b571ed046d914f4aec67415c4d327',1,'plplot::c_plmtex3()'],['../plplot_8h.html#ae285c7b126ace3cd54ef99e4aec476ec',1,'c_plmtex3():&#160;plsym.c']]],
  ['c_5fplot3d',['c_plot3d',['../plot3d_8c.html#aae337fefded3f08ac27f053a3464fdb3',1,'c_plot3d():&#160;plot3d.c'],['../namespaceplplot.html#aad2e06707141b1d9eda82255244be437',1,'plplot::c_plot3d()'],['../plplot_8h.html#ae8d88d4d369fe4bd451a3a49879d8031',1,'c_plot3d():&#160;plot3d.c']]],
  ['c_5fplot3dc',['c_plot3dc',['../plot3d_8c.html#ac5701218d06f03ade74c3915cd9a140b',1,'c_plot3dc():&#160;plot3d.c'],['../namespaceplplot.html#a97b4e3d3837b221abb3878e0cad92571',1,'plplot::c_plot3dc()'],['../plplot_8h.html#aa1810e4a628715ed5ffadc6136f48398',1,'c_plot3dc():&#160;plot3d.c']]],
  ['c_5fplot3dcl',['c_plot3dcl',['../plot3d_8c.html#a45b0e819bb606bea1e95b0d558e20179',1,'c_plot3dcl():&#160;plot3d.c'],['../namespaceplplot.html#a7a63f67ccc20ada8f58f50341a2defc0',1,'plplot::c_plot3dcl()'],['../plplot_8h.html#a44def6e9fea6c1176924d79fcf261de9',1,'c_plot3dcl():&#160;plot3d.c']]],
  ['c_5fplparseopts',['c_plparseopts',['../plargs_8c.html#a6eb48b8e3d3bf2fc20b9dcedd6758d68',1,'c_plparseopts():&#160;plargs.c'],['../namespaceplplot.html#a34a568a22760fa422589fec832197203',1,'plplot::c_plparseopts()'],['../plplot_8h.html#a38e55cb777827fb20f2232a15ae4173a',1,'c_plparseopts():&#160;plargs.c']]],
  ['c_5fplpat',['c_plpat',['../plsdef_8c.html#aed8dc25fd96706d6e20edd491fdec1d2',1,'c_plpat():&#160;plsdef.c'],['../namespaceplplot.html#a9f21e20dcd28b7e62db6fd0cfd25af9e',1,'plplot::c_plpat()'],['../plplot_8h.html#ab0aa536197dc1d89ff052966526aca11',1,'c_plpat():&#160;plsdef.c']]],
  ['c_5fplpath',['c_plpath',['../plline_8c.html#a904ff322ca1b3a5d66271dec77801d7a',1,'c_plpath():&#160;plline.c'],['../namespaceplplot.html#ac4fdd88171ca15b54ead1190bccf2a00',1,'plplot::c_plpath()'],['../plplot_8h.html#ac947f42e00e129aacc9f4ff3c327cc19',1,'c_plpath():&#160;plline.c']]],
  ['c_5fplpoin',['c_plpoin',['../plsym_8c.html#a337c764338edcbbdc0b6a992e182c4de',1,'c_plpoin():&#160;plsym.c'],['../namespaceplplot.html#a2b7fa6eb088dd812eff928823407bbc9',1,'plplot::c_plpoin()'],['../plplot_8h.html#a40101c62e44753e0fbb53bca3dda4e3d',1,'c_plpoin():&#160;plsym.c']]],
  ['c_5fplpoin3',['c_plpoin3',['../plsym_8c.html#a0a72a351c86311163dda03608caf72c0',1,'c_plpoin3():&#160;plsym.c'],['../namespaceplplot.html#ae4ff19fae5afde8b74b79f99f6bd64a2',1,'plplot::c_plpoin3()'],['../plplot_8h.html#aa85d524791c998cf7879a674d29c4a02',1,'c_plpoin3():&#160;plsym.c']]],
  ['c_5fplpoly3',['c_plpoly3',['../plline_8c.html#a2145fc50898e21ef58948a8b633125bb',1,'c_plpoly3():&#160;plline.c'],['../namespaceplplot.html#a1855a16f99ef4c6fc3f9b3c621aadc4c',1,'plplot::c_plpoly3()'],['../plplot_8h.html#a711dcee320aa37b3c05c5de09a186aaa',1,'c_plpoly3():&#160;plline.c']]],
  ['c_5fplprec',['c_plprec',['../plcore_8c.html#ab2ffc34fab68c711d27aa721b0153d13',1,'c_plprec():&#160;plcore.c'],['../namespaceplplot.html#aa3907f7f574663e3ec37dd3b907485df',1,'plplot::c_plprec()'],['../plplot_8h.html#ab6b43004c739e263fe61d819e6891c8a',1,'c_plprec():&#160;plcore.c']]],
  ['c_5fplpsty',['c_plpsty',['../plsdef_8c.html#aa14197a33a0013ea69fc257316e9acae',1,'c_plpsty():&#160;plsdef.c'],['../namespaceplplot.html#a4522f80a77dfd548aa7bed716856b499',1,'plplot::c_plpsty()'],['../plplot_8h.html#a743018ee685c7586c37d0b9102ed0d39',1,'c_plpsty():&#160;plsdef.c']]],
  ['c_5fplptex',['c_plptex',['../plsym_8c.html#aec0ffcbfc6286769f1c1cb94cd455793',1,'c_plptex():&#160;plsym.c'],['../namespaceplplot.html#a67036f2a4a27b50049b422e855c4f0c9',1,'plplot::c_plptex()'],['../plplot_8h.html#ab296b8b58169050677b720ff7564356b',1,'c_plptex():&#160;plsym.c']]],
  ['c_5fplptex3',['c_plptex3',['../plsym_8c.html#a9c632c8be5cce4a0668faeede29f80aa',1,'c_plptex3():&#160;plsym.c'],['../namespaceplplot.html#aaee7e14d276eecfd916f55a794bf3a69',1,'plplot::c_plptex3()'],['../plplot_8h.html#a308b222be7f960448b9e3b59378e746c',1,'c_plptex3():&#160;plsym.c']]],
  ['c_5fplrandd',['c_plrandd',['../plctrl_8c.html#ac9d5de2ad9d25373fa2b91b1929937c8',1,'c_plrandd():&#160;plctrl.c'],['../namespaceplplot.html#ab4820fff80380f7c289317fcf2ed5ca7',1,'plplot::c_plrandd()'],['../plplot_8h.html#acf3655ca771545e49a3d28edcef394f0',1,'c_plrandd():&#160;plctrl.c']]],
  ['c_5fplreplot',['c_plreplot',['../plcore_8c.html#a521895943ac77a578e66673a7a26ad2a',1,'c_plreplot():&#160;plcore.c'],['../namespaceplplot.html#a07d9711dc10fbf9ea7fdffb1e9d91147',1,'plplot::c_plreplot()'],['../plplot_8h.html#a54683e3343102a1ea4cf61fcaef13a8f',1,'c_plreplot():&#160;plcore.c']]],
  ['c_5fplrgbhls',['c_plrgbhls',['../plctrl_8c.html#a6c8ed7619abf08454dbb22ecb0130bb6',1,'c_plrgbhls():&#160;plctrl.c'],['../namespaceplplot.html#aa58560f9b13e65f1af751a4d475ceff6',1,'plplot::c_plrgbhls()'],['../plplot_8h.html#abb841ff8f757fca685d092cc64e2a200',1,'c_plrgbhls():&#160;plplot.h']]],
  ['c_5fplschr',['c_plschr',['../plsdef_8c.html#af1acef78b96c99f41520e46df15b7676',1,'c_plschr():&#160;plsdef.c'],['../namespaceplplot.html#a19594fe2d3a02328e079d1d129345d9c',1,'plplot::c_plschr()'],['../plplot_8h.html#a906b2f2e72c885b9783bbc6342b7c4da',1,'c_plschr():&#160;plsdef.c']]],
  ['c_5fplscmap0',['c_plscmap0',['../plctrl_8c.html#a7afa161e5608778fa50d10a462f09f11',1,'c_plscmap0():&#160;plctrl.c'],['../namespaceplplot.html#ae07e5a19342e485fb7f53ce444f87573',1,'plplot::c_plscmap0()'],['../plplot_8h.html#a04391c14259555227350b0262399243a',1,'c_plscmap0():&#160;plctrl.c']]],
  ['c_5fplscmap0a',['c_plscmap0a',['../plctrl_8c.html#a69fd6a799d093bc36149dadd1f1a0e78',1,'c_plscmap0a():&#160;plctrl.c'],['../namespaceplplot.html#af71fb1f9196678d1d6d740c1a3847ef2',1,'plplot::c_plscmap0a()'],['../plplot_8h.html#ae7b4b017186c1463ab674d4781014100',1,'c_plscmap0a():&#160;plctrl.c']]],
  ['c_5fplscmap0n',['c_plscmap0n',['../plctrl_8c.html#ac10dcf323ecaa2544b0ba42189f69deb',1,'c_plscmap0n():&#160;plctrl.c'],['../namespaceplplot.html#a0920fb5604acf977bc9aca69c47be7ed',1,'plplot::c_plscmap0n()'],['../plplot_8h.html#a06233e8a8024f3fe8079de7f607ea73f',1,'c_plscmap0n():&#160;plctrl.c']]],
  ['c_5fplscmap1',['c_plscmap1',['../plctrl_8c.html#a8e0683c50077022d92c2f9dfad1f7181',1,'c_plscmap1():&#160;plctrl.c'],['../namespaceplplot.html#accada37b9309ddf254eb1afa524a9070',1,'plplot::c_plscmap1()'],['../plplot_8h.html#ae72a5fe915a81f711cfbefc59496d4ae',1,'c_plscmap1():&#160;plctrl.c']]],
  ['c_5fplscmap1_5frange',['c_plscmap1_range',['../plctrl_8c.html#a356783ed03f984955e53e567498a2c47',1,'c_plscmap1_range():&#160;plctrl.c'],['../namespaceplplot.html#a29a94bda1aaa9b38ac3fca311f52595f',1,'plplot::c_plscmap1_range()'],['../plplot_8h.html#a15a484127420306e6d1f1c478cf51d59',1,'c_plscmap1_range():&#160;plctrl.c']]],
  ['c_5fplscmap1a',['c_plscmap1a',['../plctrl_8c.html#ab0e1bad51da63fe58c84c5af1f3eee81',1,'c_plscmap1a():&#160;plctrl.c'],['../namespaceplplot.html#a7d71c87565307799e5625c8235dbc78c',1,'plplot::c_plscmap1a()'],['../plplot_8h.html#ab63cd2760e54ba4122ba4a50232667c6',1,'c_plscmap1a():&#160;plctrl.c']]],
  ['c_5fplscmap1l',['c_plscmap1l',['../plctrl_8c.html#a48469c8e9f7ed28bd5617f5ca9e5a7b3',1,'c_plscmap1l():&#160;plctrl.c'],['../namespaceplplot.html#aecb1a2c6baba9b2d9263f7b18e72ce17',1,'plplot::c_plscmap1l()'],['../plplot_8h.html#ab3313d8d86ee93e055b34ef38efdaadb',1,'c_plscmap1l():&#160;plplot.h']]],
  ['c_5fplscmap1la',['c_plscmap1la',['../plctrl_8c.html#a001924724a00348885d38df8e63bc7cd',1,'c_plscmap1la():&#160;plctrl.c'],['../namespaceplplot.html#a24e9d59d944076ab6279b99ec08a2995',1,'plplot::c_plscmap1la()'],['../plplot_8h.html#a2e188ae3b30c9ed3292d917b8318d288',1,'c_plscmap1la():&#160;plplot.h']]],
  ['c_5fplscmap1n',['c_plscmap1n',['../plctrl_8c.html#ac161eaeed591154b3c8e0ca26c3734c8',1,'c_plscmap1n():&#160;plctrl.c'],['../namespaceplplot.html#a66f0b61d364949eab1a056889177319a',1,'plplot::c_plscmap1n()'],['../plplot_8h.html#a93963a081b30143656abd1ad77b1e7bc',1,'c_plscmap1n():&#160;plctrl.c']]],
  ['c_5fplscol0',['c_plscol0',['../plctrl_8c.html#aab58ace3e69f5191451f518919f79feb',1,'c_plscol0():&#160;plctrl.c'],['../namespaceplplot.html#ac2efd50cd2f897656cf71eca362101c0',1,'plplot::c_plscol0()'],['../plplot_8h.html#a4d5ea8fd667658ed26a7d70ce0fc5264',1,'c_plscol0():&#160;plctrl.c']]],
  ['c_5fplscol0a',['c_plscol0a',['../plctrl_8c.html#a9f453d254f50a5c56bd9c266672a1fc4',1,'c_plscol0a():&#160;plctrl.c'],['../namespaceplplot.html#a42479faafba4397a48eb085714c715a8',1,'plplot::c_plscol0a()'],['../plplot_8h.html#af75af09a57c17101f4b7b5225862b7ae',1,'c_plscol0a():&#160;plctrl.c']]],
  ['c_5fplscolbg',['c_plscolbg',['../plctrl_8c.html#ab13f6c58faf06ec39f7a5f7eab6fb1c0',1,'c_plscolbg():&#160;plctrl.c'],['../namespaceplplot.html#afd764b91fa91ae8da66d570c8f4d37a7',1,'plplot::c_plscolbg()'],['../plplot_8h.html#a559e93e1c216351277796748ca0d39d0',1,'c_plscolbg():&#160;plctrl.c']]],
  ['c_5fplscolbga',['c_plscolbga',['../plctrl_8c.html#a5d4bade8cdc36fa834041e7504744cfd',1,'c_plscolbga():&#160;plctrl.c'],['../namespaceplplot.html#a559bb58fa3e6d4ba21016c6f4d117710',1,'plplot::c_plscolbga()'],['../plplot_8h.html#afa72d07cae36a1535bf8af837aaad4ea',1,'c_plscolbga():&#160;plctrl.c']]],
  ['c_5fplscolor',['c_plscolor',['../plctrl_8c.html#ab73ff9b4223b9f7cde1dffaa8762666e',1,'c_plscolor():&#160;plctrl.c'],['../namespaceplplot.html#a920136608e27e71bfa5e29878c87108f',1,'plplot::c_plscolor()'],['../plplot_8h.html#a5e26e69ae11fc868f67768e88909c3e7',1,'c_plscolor():&#160;plctrl.c']]],
  ['c_5fplscompression',['c_plscompression',['../plcore_8c.html#a1ff4a020fb7e8ba96cb65c1749c077dd',1,'c_plscompression():&#160;plcore.c'],['../namespaceplplot.html#a6b65c95b8ff73c712de40b1c363c50e3',1,'plplot::c_plscompression()'],['../plplot_8h.html#a9104ebbbc78bdd17139db834e82c832b',1,'c_plscompression():&#160;plcore.c']]],
  ['c_5fplsdev',['c_plsdev',['../plcore_8c.html#ae372223b043f8be56436bc7e2d7662e8',1,'c_plsdev():&#160;plcore.c'],['../namespaceplplot.html#a3409c29d4fc6b6a42ff0578989f75b5c',1,'plplot::c_plsdev()'],['../plplot_8h.html#a63dcd0d0b1a3c1f54b6a8277217eb917',1,'c_plsdev():&#160;plcore.c']]],
  ['c_5fplsdidev',['c_plsdidev',['../plcore_8c.html#a3badb62009aef6999810c0d10d20516c',1,'c_plsdidev():&#160;plcore.c'],['../namespaceplplot.html#acd3fb7e953c04436d72775c3750f8cdb',1,'plplot::c_plsdidev()'],['../plplot_8h.html#ae403c84fd74141a2e18396d6a325495a',1,'c_plsdidev():&#160;plcore.c']]],
  ['c_5fplsdimap',['c_plsdimap',['../plcore_8c.html#a51cb3f6fef775355b2b1580e1307ea26',1,'c_plsdimap():&#160;plcore.c'],['../namespaceplplot.html#ab390c7e23a409ebc83487fb24bd3f4a1',1,'plplot::c_plsdimap()'],['../plplot_8h.html#afed985f4d2553562eb32cf1399b61aa5',1,'c_plsdimap():&#160;plcore.c']]],
  ['c_5fplsdiori',['c_plsdiori',['../plcore_8c.html#acb67a49f12188daff82a2ec48978d2df',1,'c_plsdiori():&#160;plcore.c'],['../namespaceplplot.html#ab73c9c095f74ca273e0fc2e6beb6e701',1,'plplot::c_plsdiori()'],['../plplot_8h.html#ad2cb5ae88431579cc0f900549613692f',1,'c_plsdiori():&#160;plcore.c']]],
  ['c_5fplsdiplt',['c_plsdiplt',['../plcore_8c.html#a3bdd5f699d95e79d94e39448172e10c2',1,'c_plsdiplt():&#160;plcore.c'],['../namespaceplplot.html#a1b320e3438c997ca5ed63daa146b22cc',1,'plplot::c_plsdiplt()'],['../plplot_8h.html#a0dbd7c3db8404977b0793c8341ceb97f',1,'c_plsdiplt():&#160;plcore.c']]],
  ['c_5fplsdiplz',['c_plsdiplz',['../plcore_8c.html#ae33ad6c295d7c38c342fc665baee5ba1',1,'c_plsdiplz():&#160;plcore.c'],['../namespaceplplot.html#ae9319937d871369ef1ac7bfa6db6f9c6',1,'plplot::c_plsdiplz()'],['../plplot_8h.html#aae802248246b9571c66dff1563a4131a',1,'c_plsdiplz():&#160;plcore.c']]],
  ['c_5fplsdrawmode',['c_plsdrawmode',['../plctrl_8c.html#a9d1d5a0877a217efc76401e557507676',1,'c_plsdrawmode(PLINT mode):&#160;plctrl.c'],['../plplot_8h.html#a00bf7735eb2174bc163fdf623ac7ea16',1,'c_plsdrawmode(PLINT mode):&#160;plctrl.c']]],
  ['c_5fplseed',['c_plseed',['../plctrl_8c.html#aac84502a5281e661d6e1f8ee8ebecb39',1,'c_plseed():&#160;plctrl.c'],['../namespaceplplot.html#ade77713fe63f4f3c796847918625aa7c',1,'plplot::c_plseed()'],['../plplot_8h.html#a1e607017d84ca2ba0425c77ca7aeb87b',1,'c_plseed():&#160;plctrl.c']]],
  ['c_5fplsesc',['c_plsesc',['../plcore_8c.html#ad34d123d1b509c1da24e3ba401787d43',1,'c_plsesc():&#160;plcore.c'],['../namespaceplplot.html#ab9c2c7637fcaf5115c364307ccc09c9a',1,'plplot::c_plsesc()'],['../plplot_8h.html#a2ce235ed573c83efff9f02a696a555ee',1,'c_plsesc():&#160;plcore.c']]],
  ['c_5fplsetopt',['c_plsetopt',['../plargs_8c.html#a58eda54275035a76e28788f1fabf0f9b',1,'c_plsetopt():&#160;plargs.c'],['../namespaceplplot.html#ad6f7295c0aee4c4cf44d383a6d9f1212',1,'plplot::c_plsetopt()'],['../plplot_8h.html#a487e1b4557470c8d2a364ecc1b9d79e0',1,'c_plsetopt():&#160;plargs.c']]],
  ['c_5fplsfam',['c_plsfam',['../plcore_8c.html#a21aa2add88af9fa23a2ea3d031637755',1,'c_plsfam():&#160;plcore.c'],['../namespaceplplot.html#ae6df129abea7da20822ab2f8e4d04c95',1,'plplot::c_plsfam()'],['../plplot_8h.html#ab3d16a3db91caab121bcb9ce80546fba',1,'c_plsfam():&#160;plcore.c']]],
  ['c_5fplsfci',['c_plsfci',['../plcore_8c.html#ac161115689719887c26b967f5ae8cc17',1,'c_plsfci():&#160;plcore.c'],['../namespaceplplot.html#a8c335543dfd6a3f04afd9e22e412bb57',1,'plplot::c_plsfci()'],['../plplot_8h.html#a074ce37141f38208e2d25ce5bb3a785b',1,'c_plsfci():&#160;plcore.c']]],
  ['c_5fplsfnam',['c_plsfnam',['../plcore_8c.html#ae483472b1b57f3281c85c6e968b607d4',1,'c_plsfnam():&#160;plcore.c'],['../namespaceplplot.html#abf9a388c1ceb8a0d0c3c5c4e1038dcdf',1,'plplot::c_plsfnam()'],['../plplot_8h.html#a5337f550e9667396f3ebf85dd8508e65',1,'c_plsfnam():&#160;plcore.c']]],
  ['c_5fplsfont',['c_plsfont',['../plsym_8c.html#a6bcba7ea478412dd64c6f8e2eb834f06',1,'c_plsfont():&#160;plsym.c'],['../namespaceplplot.html#a5b068eafc7f0e005e57efdf2345bdd75',1,'plplot::c_plsfont()'],['../plplot_8h.html#a6393d02708ce42194302ccf3b94edf47',1,'c_plsfont():&#160;plsym.c']]],
  ['c_5fplshade',['c_plshade',['../plshade_8c.html#abc5a40007856cb961f2c192c799e8ace',1,'c_plshade():&#160;plshade.c'],['../namespaceplplot.html#aff655c6b4bfe486a4826d684f7eb8162',1,'plplot::c_plshade()'],['../plplot_8h.html#a7b704b2af4c8e38945eaa60cf37b529b',1,'c_plshade():&#160;plshade.c']]],
  ['c_5fplshades',['c_plshades',['../plshade_8c.html#aa2ce196b86af4014f0f684381db7ad87',1,'c_plshades():&#160;plshade.c'],['../namespaceplplot.html#a965abbc050863a7fb8be7f8b9c95ba8c',1,'plplot::c_plshades()'],['../plplot_8h.html#ae6230a52f672b926669e78f76bc6154f',1,'c_plshades():&#160;plshade.c']]],
  ['c_5fplslabelfunc',['c_plslabelfunc',['../plbox_8c.html#a556211357054b5b8e994502b2d8d25f2',1,'c_plslabelfunc():&#160;plbox.c'],['../namespaceplplot.html#a3afe1f3514bd9954f8298df421bff580',1,'plplot::c_plslabelfunc()'],['../plplot_8h.html#ae52bcc90ec1061aecf3654dee05e56e0',1,'c_plslabelfunc():&#160;plbox.c']]],
  ['c_5fplsmaj',['c_plsmaj',['../plsdef_8c.html#aff3d7a3414c7ccf801748e9c594a8425',1,'c_plsmaj():&#160;plsdef.c'],['../namespaceplplot.html#aece3d659a68624da7636e7fa347c340e',1,'plplot::c_plsmaj()'],['../plplot_8h.html#a1c011f9eeab7ca11a5de4f2afdc2b501',1,'c_plsmaj():&#160;plsdef.c']]],
  ['c_5fplsmem',['c_plsmem',['../plcore_8c.html#a5332cad59cd8e8424274d43a50c869db',1,'c_plsmem():&#160;plcore.c'],['../namespaceplplot.html#a8dbab3b79283c14dcd32b500b512fc1e',1,'plplot::c_plsmem()'],['../plplot_8h.html#a7d89468a6bad6367bb1d64c18bd6293c',1,'c_plsmem():&#160;plcore.c']]],
  ['c_5fplsmema',['c_plsmema',['../plcore_8c.html#a7c4475f45e1b579af4b147f4cd5df58a',1,'c_plsmema(PLINT maxx, PLINT maxy, void *plotmem):&#160;plcore.c'],['../plplot_8h.html#a95631c576074df1dd45ee3cc0a1ddb70',1,'c_plsmema(PLINT maxx, PLINT maxy, PLPointer plotmem):&#160;plcore.c']]],
  ['c_5fplsmin',['c_plsmin',['../plsdef_8c.html#a15fc4e3d0e506b357aa626220152cba2',1,'c_plsmin():&#160;plsdef.c'],['../namespaceplplot.html#afb634e82ed33c8f87328c9b78521c549',1,'plplot::c_plsmin()'],['../plplot_8h.html#afaa43df242c2a6166072b2cc3cf1d1a2',1,'c_plsmin():&#160;plsdef.c']]],
  ['c_5fplsori',['c_plsori',['../plcore_8c.html#aece5565b63831fdba73b39c9a1f2ea1e',1,'c_plsori():&#160;plcore.c'],['../namespaceplplot.html#ac6700874a4b5d3e55a04206ccafa22bc',1,'plplot::c_plsori()'],['../plplot_8h.html#ae92f904189306eb1dc8f1b6641bd3c6b',1,'c_plsori():&#160;plcore.c']]],
  ['c_5fplspage',['c_plspage',['../plcore_8c.html#ad12f661799506496b1172332fd00e54f',1,'c_plspage():&#160;plcore.c'],['../namespaceplplot.html#a5faaf381f93b54562b9770d83362b5c8',1,'plplot::c_plspage()'],['../plplot_8h.html#a993d2bc54f3dd8d7432fe9e2d8ce1b09',1,'c_plspage():&#160;plcore.c']]],
  ['c_5fplspal0',['c_plspal0',['../plctrl_8c.html#ac2b5aaa3dff38015e6ea5c2c41e61601',1,'c_plspal0():&#160;plctrl.c'],['../namespaceplplot.html#af005a6a8034510f226b39e43caf7860a',1,'plplot::c_plspal0()'],['../plplot_8h.html#a6992097a97fa026f4db8515bcba58470',1,'c_plspal0():&#160;plctrl.c']]],
  ['c_5fplspal1',['c_plspal1',['../plctrl_8c.html#a233c2dadb7a88c7703f9b7ca9869d8a8',1,'c_plspal1():&#160;plctrl.c'],['../namespaceplplot.html#a60bec4b2a44cfe04f6e23060a4d50d1c',1,'plplot::c_plspal1()'],['../plplot_8h.html#a0f29de7505c496be50efa2d191d5de09',1,'c_plspal1():&#160;plctrl.c']]],
  ['c_5fplspause',['c_plspause',['../plcore_8c.html#a6a3b37f7cfbc34a552b4bf20308aa79d',1,'c_plspause():&#160;plcore.c'],['../namespaceplplot.html#aad4df2664d5f6ae82dff7c55544e4e43',1,'plplot::c_plspause()'],['../plplot_8h.html#aedc6099dad1ae3e4f444b76a28e06b9a',1,'c_plspause():&#160;plcore.c']]],
  ['c_5fplsstrm',['c_plsstrm',['../plcore_8c.html#aa1e9f431367c59a195f1a8cd9e2227c1',1,'c_plsstrm():&#160;plcore.c'],['../namespaceplplot.html#ae21f336a8237340b039a0ca3c849b949',1,'plplot::c_plsstrm()'],['../plplot_8h.html#a3cae7c0e783e917bd5d2c25adfdce6fd',1,'c_plsstrm():&#160;plcore.c']]],
  ['c_5fplssub',['c_plssub',['../plcore_8c.html#a3f508d621ee47b67d42f656edc0aa9c7',1,'c_plssub():&#160;plcore.c'],['../namespaceplplot.html#adfc9ae0867311b43cde87d6c733bd479',1,'plplot::c_plssub()'],['../plplot_8h.html#ab23fbc49ed42a65bc6d9f51321d2497d',1,'c_plssub():&#160;plcore.c']]],
  ['c_5fplssym',['c_plssym',['../plsdef_8c.html#a54e0770c4bf0e7ce9f405dde72f261c2',1,'c_plssym():&#160;plsdef.c'],['../namespaceplplot.html#ae6219d749ee7630013cc5e6f91a64af9',1,'plplot::c_plssym()'],['../plplot_8h.html#a940a97b378a847bd9699d0e18162d57e',1,'c_plssym():&#160;plsdef.c']]],
  ['c_5fplstar',['c_plstar',['../plcore_8c.html#a3d15fa158e627ba1582fbad9271c797b',1,'c_plstar():&#160;plcore.c'],['../namespaceplplot.html#a80ca439ae6fe5db885c066ec461efa62',1,'plplot::c_plstar()'],['../plplot_8h.html#a1690af1bfe3d5c00784fdb9e68d830f9',1,'c_plstar():&#160;plcore.c']]],
  ['c_5fplstart',['c_plstart',['../plcore_8c.html#a30abc7821b66912c4103c994c2e009ee',1,'c_plstart():&#160;plcore.c'],['../namespaceplplot.html#a23d9f44ae538a81b5989f284583e0cf6',1,'plplot::c_plstart()'],['../plplot_8h.html#acf171cdde28a0ee9c413c912d359420c',1,'c_plstart():&#160;plcore.c']]],
  ['c_5fplstransform',['c_plstransform',['../plcore_8c.html#a437721a29e32435183c99fa8e9e5f5a2',1,'c_plstransform():&#160;plcore.c'],['../namespaceplplot.html#a247e7fabb00a5f2ac6d81385d366709b',1,'plplot::c_plstransform()'],['../plplot_8h.html#ab4f5d2715b351a7215907a11ecca92e9',1,'c_plstransform():&#160;plcore.c']]],
  ['c_5fplstring',['c_plstring',['../plsym_8c.html#a342c77b0761f0c7c6be8e8df2f60f4ea',1,'c_plstring():&#160;plsym.c'],['../namespaceplplot.html#a31a1d0908fcb030d73f2454fd5315114',1,'plplot::c_plstring()'],['../plplot_8h.html#a8422af8d77d66646808e57f0585934a5',1,'c_plstring():&#160;plsym.c']]],
  ['c_5fplstring3',['c_plstring3',['../plsym_8c.html#a3723083bc0d76615f416937ec59bae5b',1,'c_plstring3():&#160;plsym.c'],['../namespaceplplot.html#a69b4ec3b9328c306109dad867b0c6dab',1,'plplot::c_plstring3()'],['../plplot_8h.html#ac8a61d7c6fae85234acbe7ca5983e94c',1,'c_plstring3():&#160;plsym.c']]],
  ['c_5fplstripa',['c_plstripa',['../plstripc_8c.html#ade08cf4f557157f5fdb772791a90ae1c',1,'c_plstripa():&#160;plstripc.c'],['../namespaceplplot.html#a108b680da31e4c7a095f3473b60786ee',1,'plplot::c_plstripa()'],['../plplot_8h.html#a7635fe351043aa7138a17a7d4b7ba2a4',1,'c_plstripa():&#160;plstripc.c']]],
  ['c_5fplstripc',['c_plstripc',['../plstripc_8c.html#ac4e57dc3015e76eca6aae1e499d6b2b9',1,'c_plstripc():&#160;plstripc.c'],['../namespaceplplot.html#a32aa2b808e423b153f9f3eb030b3c51f',1,'plplot::c_plstripc()'],['../plplot_8h.html#a9b0db1d8eda5c3e71f371b78fcc92be3',1,'c_plstripc():&#160;plplot.h']]],
  ['c_5fplstripd',['c_plstripd',['../plstripc_8c.html#a68ec90634b01e08a86085424522a8c17',1,'c_plstripd():&#160;plstripc.c'],['../namespaceplplot.html#a84b3127d90d825393c1fbb0316a30644',1,'plplot::c_plstripd()'],['../plplot_8h.html#a46d05136dd3eafedef0aab7012cfaacb',1,'c_plstripd():&#160;plstripc.c']]],
  ['c_5fplstyl',['c_plstyl',['../plline_8c.html#a968863f2b50fead0287a3e1aca004f72',1,'c_plstyl():&#160;plline.c'],['../namespaceplplot.html#a924d8f64da03bc1a5e4e0e0967d93d79',1,'plplot::c_plstyl()'],['../plplot_8h.html#a21db391b65d6c42f34008e74e3d4f68c',1,'c_plstyl():&#160;plline.c']]],
  ['c_5fplsurf3d',['c_plsurf3d',['../plot3d_8c.html#a211fd1c0ab3bed352c7835417d4e87c1',1,'c_plsurf3d():&#160;plot3d.c'],['../namespaceplplot.html#ac18743efda3f9dff0dc24c6dc292ba77',1,'plplot::c_plsurf3d()'],['../plplot_8h.html#a7e0dd6508f192868256b850d8c2fe803',1,'c_plsurf3d():&#160;plot3d.c']]],
  ['c_5fplsurf3dl',['c_plsurf3dl',['../plot3d_8c.html#a78c43082eb4ca596a741f1dab66cf098',1,'c_plsurf3dl():&#160;plot3d.c'],['../namespaceplplot.html#ad35774ef7ff45374a25f3900fba734eb',1,'plplot::c_plsurf3dl()'],['../plplot_8h.html#af1790e938f7b92c6b698f3dae6d06060',1,'c_plsurf3dl():&#160;plot3d.c']]],
  ['c_5fplsvect',['c_plsvect',['../plvect_8c.html#a39b741b306c3743f779c6b86673bc50d',1,'c_plsvect():&#160;plvect.c'],['../namespaceplplot.html#a72613f978d226b4a897c4d7269c56dd1',1,'plplot::c_plsvect()'],['../plplot_8h.html#a3a9507e916cfa4dbd4a146ec71082003',1,'c_plsvect():&#160;plvect.c']]],
  ['c_5fplsvpa',['c_plsvpa',['../plvpor_8c.html#a6f1ebe539a82b9e581191f422981254d',1,'c_plsvpa():&#160;plvpor.c'],['../namespaceplplot.html#a2b15e0d17c27ac69d0501c23a2818848',1,'plplot::c_plsvpa()'],['../plplot_8h.html#a56d8a17aa2d0a673c802ea948abcdc1c',1,'c_plsvpa():&#160;plvpor.c']]],
  ['c_5fplsxax',['c_plsxax',['../plcore_8c.html#aca008e616ba21f5d1f51618e0cfe9064',1,'c_plsxax():&#160;plcore.c'],['../namespaceplplot.html#afacd806428c2be8dd8f86ae3fe5d7a84',1,'plplot::c_plsxax()'],['../plplot_8h.html#a6dcf30171cd60db19a3dbf5bc78e3aae',1,'c_plsxax():&#160;plcore.c']]],
  ['c_5fplsyax',['c_plsyax',['../plcore_8c.html#aae7ebd3c9503d19ef16d9dbe0236e709',1,'c_plsyax():&#160;plcore.c'],['../namespaceplplot.html#a84a37999ae9afa6db889d6e77e058e2a',1,'plplot::c_plsyax()'],['../plplot_8h.html#a3603d38d28846b15c54a114afdfb28c1',1,'c_plsyax():&#160;plcore.c']]],
  ['c_5fplsym',['c_plsym',['../plsym_8c.html#a1173191d14b17877b0fa19c457bb3518',1,'c_plsym():&#160;plsym.c'],['../namespaceplplot.html#ae83b3ce6296a1932455a976c8262b0a6',1,'plplot::c_plsym()'],['../plplot_8h.html#ac001d9cf28e7b3160b62f787fec91a10',1,'c_plsym():&#160;plsym.c']]],
  ['c_5fplszax',['c_plszax',['../plcore_8c.html#a3170cad72924f63f2fe03055f355cb95',1,'c_plszax():&#160;plcore.c'],['../namespaceplplot.html#a7cd456b38d1a02f958df83d81c15eeea',1,'plplot::c_plszax()'],['../plplot_8h.html#ae4e2f908751b0a68b5bc599a2e8d50a4',1,'c_plszax():&#160;plcore.c']]],
  ['c_5fpltext',['c_pltext',['../plctrl_8c.html#a4c415dc78101b686ddd487d8f0dcc24f',1,'c_pltext():&#160;plctrl.c'],['../namespaceplplot.html#a426135b864521001f1048223f4d97bf1',1,'plplot::c_pltext()'],['../plplot_8h.html#a94c1af262a2855684ddeeea0d13e3fa5',1,'c_pltext():&#160;plctrl.c']]],
  ['c_5fpltimefmt',['c_pltimefmt',['../pltime_8c.html#a58c5f37950e02f670b372534da7ef04c',1,'c_pltimefmt():&#160;pltime.c'],['../namespaceplplot.html#aae6cd0577e41bed837f0df5766dd203e',1,'plplot::c_pltimefmt()'],['../plplot_8h.html#aff9a3a7ee09c2c1c4076058aa07cc4eb',1,'c_pltimefmt():&#160;pltime.c']]],
  ['c_5fplvasp',['c_plvasp',['../plvpor_8c.html#a61eccae47199b96f3cf1e68955998a47',1,'c_plvasp():&#160;plvpor.c'],['../namespaceplplot.html#af28bc6aa01b3bda2fb22dd2988beb6e9',1,'plplot::c_plvasp()'],['../plplot_8h.html#a6d0c2a4be40790e91824ad0b7bac0bec',1,'c_plvasp():&#160;plvpor.c']]],
  ['c_5fplvect',['c_plvect',['../plvect_8c.html#ab36164048c3c08f3e139c619e7d9568e',1,'c_plvect():&#160;plvect.c'],['../namespaceplplot.html#abfe95f7e5cee37e1b7c449c1bde17854',1,'plplot::c_plvect()'],['../plplot_8h.html#a12842a5955e8151ee92f4904d60c0066',1,'c_plvect():&#160;plvect.c']]],
  ['c_5fplvpas',['c_plvpas',['../plvpor_8c.html#a78a625661389b35e5678e7d5b88722c2',1,'c_plvpas():&#160;plvpor.c'],['../namespaceplplot.html#a9db90eb66c2c80dd6f4d40c60d361a53',1,'plplot::c_plvpas()'],['../plplot_8h.html#abd8a7e0ae9bb0da76807e7e0bf93e3a4',1,'c_plvpas():&#160;plvpor.c']]],
  ['c_5fplvpor',['c_plvpor',['../plvpor_8c.html#a3deca6d002c87668a1ea23c2e58a354c',1,'c_plvpor():&#160;plvpor.c'],['../namespaceplplot.html#aafb44a4d4a54f5a5dd45c089b69a76e2',1,'plplot::c_plvpor()'],['../plplot_8h.html#a5fd547420fef9e958c4026bc2e9c4898',1,'c_plvpor():&#160;plvpor.c']]],
  ['c_5fplvsta',['c_plvsta',['../plvpor_8c.html#a631c030c812252a8a613572bbe1270ef',1,'c_plvsta():&#160;plvpor.c'],['../namespaceplplot.html#adf0f30dfd998a1253eab87d34fae0586',1,'plplot::c_plvsta()'],['../plplot_8h.html#ad6443e9ab2395017d048b8efb06e2ee2',1,'c_plvsta():&#160;plvpor.c']]],
  ['c_5fplw3d',['c_plw3d',['../plwind_8c.html#ab3eace915c4efc4cade6c6654ebec2e0',1,'c_plw3d():&#160;plwind.c'],['../namespaceplplot.html#aa418c196c1f05952dbebfef67071846d',1,'plplot::c_plw3d()'],['../plplot_8h.html#a44e37b421e4b094322c520057dcd317d',1,'c_plw3d():&#160;plwind.c']]],
  ['c_5fplwidth',['c_plwidth',['../plcore_8c.html#a7e8aa99d537c6041b805f360f5c2b81c',1,'c_plwidth():&#160;plcore.c'],['../namespaceplplot.html#ac139793483186b792df01ce773ffe2be',1,'plplot::c_plwidth()'],['../plplot_8h.html#a35b056d50ccc18dab5832a99268e04ef',1,'c_plwidth():&#160;plcore.c']]],
  ['c_5fplwind',['c_plwind',['../plwind_8c.html#a29212e20abf13036271f1024db71fcd0',1,'c_plwind():&#160;plwind.c'],['../namespaceplplot.html#ab9aa6fab9ceb4a738f32415851035a7d',1,'plplot::c_plwind()'],['../plplot_8h.html#a02525a7edb3a826dc05004ed517263b9',1,'c_plwind():&#160;plwind.c']]],
  ['c_5fplxormod',['c_plxormod',['../plctrl_8c.html#a0d37f61f0fc93cdf16d4afffa2c4b28d',1,'c_plxormod():&#160;plctrl.c'],['../namespaceplplot.html#a4b47230cae3dd41861550e900b35b8c6',1,'plplot::c_plxormod()'],['../plplot_8h.html#a253a53d4c29ddbc1060d36b0ebc55a0e',1,'c_plxormod():&#160;plplot.h']]],
  ['c_5fto_5fcharacter_5farray',['c_to_character_array',['../namespaceplplot__private__utilities.html#add53eaa77165db468f24d7ccb9509913',1,'plplot_private_utilities']]],
  ['cairo_5ffamily_5fcheck',['cairo_family_check',['../cairo_8c.html#af34b94fb2d1775703e4b35093f0e34f3',1,'cairo.c']]],
  ['calc_5fdidev',['calc_didev',['../plcore_8c.html#a26b8467bc1909781bdc9d74960d6d238',1,'calc_didev(void):&#160;plcore.c'],['../plcore_8h.html#a26b8467bc1909781bdc9d74960d6d238',1,'calc_didev(void):&#160;plcore.h']]],
  ['calc_5fdimap',['calc_dimap',['../plcore_8c.html#a0e92f358a43acd5c2fe68e40433a7b9c',1,'calc_dimap():&#160;plcore.c'],['../plcore_8h.html#ae79b9781138a1e5eaab96fc96015fbdb',1,'calc_dimap(void):&#160;plcore.h']]],
  ['calc_5fdiori',['calc_diori',['../plcore_8c.html#a7a2547ac4d7cc4edab10361ca81f983d',1,'calc_diori(void):&#160;plcore.c'],['../plcore_8h.html#a7a2547ac4d7cc4edab10361ca81f983d',1,'calc_diori(void):&#160;plcore.h']]],
  ['calc_5fdiplt',['calc_diplt',['../plcore_8c.html#aaa88349701dbf79cbe3459271e11913d',1,'calc_diplt(void):&#160;plcore.c'],['../plcore_8h.html#aaa88349701dbf79cbe3459271e11913d',1,'calc_diplt(void):&#160;plcore.h']]],
  ['calc_5fworld',['calc_world',['../classplstream.html#ad96c824f1136684bae32c89d1d49e67c',1,'plstream']]],
  ['calculate_5flimits',['calculate_limits',['../pllegend_8c.html#aaeb3cac4f2e493e3bd6f35d8ea8d1252',1,'pllegend.c']]],
  ['cast',['cast',['../classoctave__swig__type.html#ae5ca39cd664c4bb9a367963fdbec089a',1,'octave_swig_type']]],
  ['catch_5fsegv',['catch_segv',['../test-drv-info_8c.html#af22f5388e7ee43a03372108a354ea57f',1,'catch_segv(int sig):&#160;test-drv-info.c'],['../test-drv-info_8c.html#ad0e945613ff49177b9c683f33a5e98e8',1,'catch_segv(int PL_UNUSED(sig)):&#160;test-drv-info.c']]],
  ['cdaddelem',['cdAddElem',['../cd_8c.html#a69ad2b5c2a19c23537506d551bb9e65c',1,'cd.c']]],
  ['cdappbyte',['cdAppByte',['../cd_8c.html#adbac702642a32ac50cd549eb58efb98e',1,'cd.c']]],
  ['cdappnull',['cdAppNull',['../cd_8c.html#ae85e1c3eb8cc5d60d5414f22ce7b5c3e',1,'cd.c']]],
  ['cdappshort',['cdAppShort',['../cd_8c.html#ab92ec2140ace66ac38dc95e6e9c0a7b5',1,'cd.c']]],
  ['cdarc3pt',['cdArc3Pt',['../cd_8c.html#a9b4f04d2357c653deaa9f2ee4d273716',1,'cdArc3Pt(cdImagePtr im, int sx, int sy, int ix, int iy, int ex, int ey):&#160;cd.c'],['../cd_8h.html#af4aa56b0c1e4157a3b4e002390d98b18',1,'cdArc3Pt(cdImagePtr im, int sx, int sy, int ix, int iy, int ex, int ey):&#160;cd.c']]],
  ['cdarc3ptclose',['cdArc3PtClose',['../cd_8c.html#adf7ce558869744b31105aabb982b632a',1,'cdArc3PtClose(cdImagePtr im, int sx, int sy, int ix, int iy, int ex, int ey, int cl):&#160;cd.c'],['../cd_8h.html#a5a106719b5af463cc7585f1ec1a052ef',1,'cdArc3PtClose(cdImagePtr im, int sx, int sy, int ix, int iy, int ex, int ey, int cl):&#160;cd.c']]],
  ['cdcgmheader',['cdCgmHeader',['../cd_8c.html#a63feaaa3a173971176f56dd2097882c9',1,'cdCgmHeader(cdImagePtr im):&#160;cd.c'],['../cd_8h.html#aa82ac21fad44d33dd720440e93b87476',1,'cdCgmHeader(cdImagePtr):&#160;cd.c']]],
  ['cdcgmnewpic',['cdCgmNewPic',['../cd_8c.html#a4397808ed3da18abcfb8043f1fe6fff5',1,'cdCgmNewPic(cdImagePtr im, int sticky):&#160;cd.c'],['../cd_8h.html#afb060f29938aff4254e673e2c95063e8',1,'cdCgmNewPic(cdImagePtr im, int sticky):&#160;cd.c']]],
  ['cdcgmpic',['cdCgmPic',['../cd_8c.html#aa2b47b053634c823cc3de59cafae167a',1,'cdCgmPic(cdImagePtr im, int sticky):&#160;cd.c'],['../cd_8h.html#a4a39157fd39cb8742bc8e4dd3d5a81fb',1,'cdCgmPic(cdImagePtr, int):&#160;cd.c']]],
  ['cdcircle',['cdCircle',['../cd_8c.html#a7ab4de787ddc980ae1d3455768822bfa',1,'cdCircle(cdImagePtr im, int cx, int cy, int r):&#160;cd.c'],['../cd_8h.html#a8c4f02a7e35cf08fae3d2c48a45a5965',1,'cdCircle(cdImagePtr im, int cx, int cy, int r):&#160;cd.c']]],
  ['cdcomhead',['cdcomhead',['../cd_8c.html#acb3867a7def25cafc6cb3c0fd9e47413',1,'cd.c']]],
  ['cdcomheadlong',['cdcomheadlong',['../cd_8c.html#a6bfd5a5543ec62851be4c6e9d113108f',1,'cd.c']]],
  ['cdellipse',['cdEllipse',['../cd_8c.html#a3c43a64820202ab737b9acc998d65244',1,'cdEllipse(cdImagePtr im, int cx, int cy, int d1x, int d1y, int d2x, int d2y):&#160;cd.c'],['../cd_8h.html#ad1a2331bf88562232e4ccd0db11c7737',1,'cdEllipse(cdImagePtr im, int cx, int cy, int d1x, int d1y, int d2x, int d2y):&#160;cd.c']]],
  ['cdimageaddcolor',['cdImageAddColor',['../cd_8c.html#ad1e20e57e186115d339e019f96cb0b13',1,'cd.c']]],
  ['cdimageaddcolorindex',['cdImageAddColorIndex',['../cd_8c.html#a27849988c61e79c333e2b5a8c086177c',1,'cd.c']]],
  ['cdimageaddfont',['cdImageAddFont',['../cd_8c.html#ad1d9dae4677cc24a0cd9d5b6f0244def',1,'cdImageAddFont(cdImagePtr im, const char *fontname):&#160;cd.c'],['../cd_8h.html#a7efcc151f8a09909ab4b59f5a7b57100',1,'cdImageAddFont(cdImagePtr im, const char *fontname):&#160;cd.c']]],
  ['cdimageboundssafe',['cdImageBoundsSafe',['../cd_8c.html#a420daa41ffa2f45491bb246a5c0c5f9a',1,'cdImageBoundsSafe(cdImagePtr im, int x, int y):&#160;cd.c'],['../cd_8h.html#a37b7ec2036fa7f51681dd0665b140922',1,'cdImageBoundsSafe(cdImagePtr im, int x, int y):&#160;cd.c']]],
  ['cdimagecgm',['cdImageCgm',['../cd_8c.html#a40dc37383358dbeeee07bf468414db31',1,'cdImageCgm(cdImagePtr im, FILE *out):&#160;cd.c'],['../cd_8h.html#a9acfd52728fa3952b59a7ac5d002c964',1,'cdImageCgm(cdImagePtr im, FILE *):&#160;cd.c']]],
  ['cdimageclearfonts',['cdImageClearFonts',['../cd_8c.html#a5cebc06415461356c8a828fdf18b74aa',1,'cdImageClearFonts(cdImagePtr im):&#160;cd.c'],['../cd_8h.html#aabaa57451d0799148ea669a1424f437b',1,'cdImageClearFonts(cdImagePtr im):&#160;cd.c']]],
  ['cdimagecolor16',['cdImageColor16',['../cd_8c.html#ad4681fedaa26e845d58cf1ab7d1019fb',1,'cdImageColor16(cdImagePtr im):&#160;cd.c'],['../cd_8h.html#a79351bc39f32c39840cb4eebaaf0af4e',1,'cdImageColor16(cdImagePtr im):&#160;cd.c']]],
  ['cdimagecolorallocate',['cdImageColorAllocate',['../cd_8c.html#aabef9e71a2c0b18b900e78cbf261a532',1,'cdImageColorAllocate(cdImagePtr im, int r, int g, int b):&#160;cd.c'],['../cd_8h.html#a34af79e97187993c3243a3da5189ebbf',1,'cdImageColorAllocate(cdImagePtr im, int r, int g, int b):&#160;cd.c']]],
  ['cdimagecolorclear',['cdImageColorClear',['../cd_8c.html#a97e5d639e3493b73b545f6639539da55',1,'cdImageColorClear(cdImagePtr im):&#160;cd.c'],['../cd_8h.html#a1b3a0dd78f4ad88c6b766410c3ca6074',1,'cdImageColorClear(cdImagePtr im):&#160;cd.c']]],
  ['cdimagecolorclosest',['cdImageColorClosest',['../cd_8c.html#af7f7a08cdafd805012b0d08c7b17f23d',1,'cdImageColorClosest(cdImagePtr im, int r, int g, int b):&#160;cd.c'],['../cd_8h.html#a7f8e3ac1487f4e5bf3c9f5452f251c41',1,'cdImageColorClosest(cdImagePtr im, int r, int g, int b):&#160;cd.c']]],
  ['cdimagecolordeallocate',['cdImageColorDeallocate',['../cd_8c.html#a3a72629e355c34109531d5df1c0ab489',1,'cdImageColorDeallocate(cdImagePtr im, int color):&#160;cd.c'],['../cd_8h.html#aaa12309ae7891a8547e1c3103a005fc0',1,'cdImageColorDeallocate(cdImagePtr, int):&#160;cd.c']]],
  ['cdimagecolorexact',['cdImageColorExact',['../cd_8c.html#a73fcb7a0756acf8c7aa9bf2702410011',1,'cdImageColorExact(cdImagePtr im, int r, int g, int b):&#160;cd.c'],['../cd_8h.html#a045b794b6e4196af5e2332bc34de5ed9',1,'cdImageColorExact(cdImagePtr im, int r, int g, int b):&#160;cd.c']]],
  ['cdimagecreate',['cdImageCreate',['../cd_8c.html#afc6da1144ca33f042cd6c1eedc4e4f6a',1,'cdImageCreate(int sx, int sy):&#160;cd.c'],['../cd_8h.html#a6fc531d340113cf535e2e170cfb589bc',1,'cdImageCreate(int sx, int sy):&#160;cd.c']]],
  ['cdimagedashedline',['cdImageDashedLine',['../cd_8c.html#a961f968f5b4130dd68e0706f7888a9a8',1,'cd.c']]],
  ['cdimagedestroy',['cdImageDestroy',['../cd_8c.html#af07c46dbd1405df3348d90630ca5a822',1,'cdImageDestroy(cdImagePtr im):&#160;cd.c'],['../cd_8h.html#ae5e592bb73fea49ec6d6655bd9d52522',1,'cdImageDestroy(cdImagePtr im):&#160;cd.c']]],
  ['cdimageendcgm',['cdImageEndCgm',['../cd_8c.html#a9134d7f2f087a95e0cead292c8ee2e9c',1,'cdImageEndCgm(cdImagePtr im):&#160;cd.c'],['../cd_8h.html#adb9145d885573dd891732c9fc6058fbb',1,'cdImageEndCgm(cdImagePtr im):&#160;cd.c']]],
  ['cdimageendpic',['cdImageEndPic',['../cd_8c.html#a6c5bb8f3a9b9e0bd2494af368ff00322',1,'cdImageEndPic(cdImagePtr im):&#160;cd.c'],['../cd_8h.html#a9fd353db56fee24b2c33ae02ea8c8414',1,'cdImageEndPic(cdImagePtr im):&#160;cd.c']]],
  ['cdimageline',['cdImageLine',['../cd_8c.html#afb813e5f8a41498acfaf4af4cbb46ab1',1,'cdImageLine(cdImagePtr im, int x1, int y1, int x2, int y2, int color):&#160;cd.c'],['../cd_8h.html#a4d87de988632e17047b1f9dd7c96337f',1,'cdImageLine(cdImagePtr im, int x1, int y1, int x2, int y2, int color):&#160;cd.c']]],
  ['cdimagerectangle',['cdImageRectangle',['../cd_8c.html#a9d48d0c1ff9497e6af32242a06e3d863',1,'cdImageRectangle(cdImagePtr im, int x1, int y1, int x2, int y2, int color):&#160;cd.c'],['../cd_8h.html#a7a7eb663cebdcd2483fe0ddb4da2d16e',1,'cdImageRectangle(cdImagePtr im, int x1, int y1, int x2, int y2, int color):&#160;cd.c']]],
  ['cdimagesetdefaults',['cdImageSetDefaults',['../cd_8c.html#a34b20878789d6b73ad4eba1473965096',1,'cdImageSetDefaults(cdImagePtr im):&#160;cd.c'],['../cd_8h.html#af2d8ad5db49fad9b89daec8cf25752cd',1,'cdImageSetDefaults(cdImagePtr im):&#160;cd.c']]],
  ['cdimagesetedgespec',['cdImageSetEdgeSpec',['../cd_8c.html#a32d7050f79a0024dd1460ae8600a341a',1,'cdImageSetEdgeSpec(cdImagePtr im, int specmode):&#160;cd.c'],['../cd_8h.html#a1b5aa2acc2d58cc6fddedb44051b37c1',1,'cdImageSetEdgeSpec(cdImagePtr im, int specmode):&#160;cd.c']]],
  ['cdimagesetlinespec',['cdImageSetLineSpec',['../cd_8c.html#a57d295a9051de2477f908ba6fac70003',1,'cdImageSetLineSpec(cdImagePtr im, int specmode):&#160;cd.c'],['../cd_8h.html#a78eaebf21441b3a3ad62b42f4c371a24',1,'cdImageSetLineSpec(cdImagePtr im, int specmode):&#160;cd.c']]],
  ['cdimagesetmarkerspec',['cdImageSetMarkerSpec',['../cd_8c.html#ad06affa826428f8300e0778760e75ea2',1,'cdImageSetMarkerSpec(cdImagePtr im, int specmode):&#160;cd.c'],['../cd_8h.html#a4d3daa66ed7a4bc1a5590b37de644e4b',1,'cdImageSetMarkerSpec(cdImagePtr im, int specmode):&#160;cd.c']]],
  ['cdimagesetoutput',['cdImageSetOutput',['../cd_8c.html#a6a3369e49a29e1be4367d5591da650f4',1,'cdImageSetOutput(cdImagePtr im, FILE *output):&#160;cd.c'],['../cd_8h.html#a7ddfd9c6272521d9d102a1f118a8c855',1,'cdImageSetOutput(cdImagePtr im, FILE *output):&#160;cd.c']]],
  ['cdimagesetsize',['cdImageSetSize',['../cd_8c.html#a239677e0b77fa7b6c57713a65c573e30',1,'cdImageSetSize(cdImagePtr im, int x, int y):&#160;cd.c'],['../cd_8h.html#a59bcc62e2671c5711dab7e42d77f77e5',1,'cdImageSetSize(cdImagePtr im, int x, int y):&#160;cd.c']]],
  ['cdimagestartcgm',['cdImageStartCgm',['../cd_8c.html#a944d99e49fe84ffc7955fce62dd094b0',1,'cdImageStartCgm():&#160;cd.c'],['../cd_8h.html#a1b0aeae248677eabeb6554ec5f289c79',1,'cdImageStartCgm():&#160;cd.c']]],
  ['cdline',['cdLine',['../cd_8c.html#a57cf0662cbedc48ef5210958751b32d4',1,'cdLine(cdImagePtr im, int x1, int y1, int x2, int y2):&#160;cd.c'],['../cd_8h.html#a3894607b83b93a94e029aea480f90e4f',1,'cdLine(cdImagePtr im, int x1, int y1, int x2, int y2):&#160;cd.c']]],
  ['cdmarker',['cdMarker',['../cd_8c.html#a4eeaf8f75f92135c9fe98c9dc71515c1',1,'cdMarker(cdImagePtr im, int x, int y):&#160;cd.c'],['../cd_8h.html#a1c871e9d01d7d03f60511058f24bab9e',1,'cdMarker(cdImagePtr im, int x, int y):&#160;cd.c']]],
  ['cdpolygon',['cdPolygon',['../cd_8c.html#aa64c080c23d15fb3a51b3629989236d0',1,'cdPolygon(cdImagePtr im, cdPointPtr p, int n):&#160;cd.c'],['../cd_8h.html#a91f6c931defa4a5678bd7110d78a5b7b',1,'cdPolygon(cdImagePtr im, cdPointPtr p, int n):&#160;cd.c']]],
  ['cdpolygonset',['cdPolygonSet',['../cd_8c.html#a00ab520bbd723778b0c70c7d8ebdee48',1,'cdPolygonSet(cdImagePtr im, cdPointPtr p, int n):&#160;cd.c'],['../cd_8h.html#a901d6691711f1faad0c5b9d3ea7a2174',1,'cdPolygonSet(cdImagePtr im, cdPointPtr p, int n):&#160;cd.c']]],
  ['cdpolyline',['cdPolyLine',['../cd_8c.html#a43da061f2e9d2971b6145db476e6c875',1,'cdPolyLine(cdImagePtr im, cdPointPtr p, int n):&#160;cd.c'],['../cd_8h.html#a4b09eb73c7fb7d8e43ae6a2f7bed5b93',1,'cdPolyLine(cdImagePtr im, cdPointPtr p, int n):&#160;cd.c']]],
  ['cdpolymarker',['cdPolyMarker',['../cd_8c.html#a327a64e25a0c7ad9300d3145f591a863',1,'cdPolyMarker(cdImagePtr im, cdPointPtr p, int n):&#160;cd.c'],['../cd_8h.html#a436ec5be1eac5d5ca6160b1b2994400a',1,'cdPolyMarker(cdImagePtr im, cdPointPtr p, int n):&#160;cd.c']]],
  ['cdrectangle',['cdRectangle',['../cd_8c.html#adfaea53e8609c907001ba65492a2646b',1,'cdRectangle(cdImagePtr im, int x1, int y1, int x2, int y2):&#160;cd.c'],['../cd_8h.html#a97ecc9b67774bd1d3bc94af73bf89e1f',1,'cdRectangle(cdImagePtr im, int x1, int y1, int x2, int y2):&#160;cd.c']]],
  ['cdsetedgecolor',['cdSetEdgeColor',['../cd_8c.html#a1e6b644812fc516a515e1dc2bbb23376',1,'cdSetEdgeColor(cdImagePtr im, int edcolor):&#160;cd.c'],['../cd_8h.html#abaa37fd22db4a28a945624c0dc6166f8',1,'cdSetEdgeColor(cdImagePtr im, int edcolor):&#160;cd.c']]],
  ['cdsetedgetype',['cdSetEdgeType',['../cd_8c.html#a9b45300ee9131d8c0acb8ba5627a8b3c',1,'cdSetEdgeType(cdImagePtr im, int edtype):&#160;cd.c'],['../cd_8h.html#a874f30a40a639447b6da801ed196858e',1,'cdSetEdgeType(cdImagePtr im, int edtype):&#160;cd.c']]],
  ['cdsetedgevis',['cdSetEdgeVis',['../cd_8c.html#a204a3b677bde03407f25e88ab64226bf',1,'cdSetEdgeVis(cdImagePtr im, int edvis):&#160;cd.c'],['../cd_8h.html#ae63c14a9f93164ab3a7e495465296ede',1,'cdSetEdgeVis(cdImagePtr im, int edvis):&#160;cd.c']]],
  ['cdsetedgewidth',['cdSetEdgeWidth',['../cd_8c.html#a0e8e9ab4e592ee125bf2008c6c3c0b30',1,'cdSetEdgeWidth(cdImagePtr im, int edwidth):&#160;cd.c'],['../cd_8h.html#a55b87c1bcaee3a6bb4d08775f3ec71f3',1,'cdSetEdgeWidth(cdImagePtr im, int edwidth):&#160;cd.c']]],
  ['cdsetfillcolor',['cdSetFillColor',['../cd_8c.html#ac0f7e6594671b171f3e32cb0bb856f81',1,'cdSetFillColor(cdImagePtr im, int incolor):&#160;cd.c'],['../cd_8h.html#acda6912c19c2eb65c3d37031ee115844',1,'cdSetFillColor(cdImagePtr im, int incolor):&#160;cd.c']]],
  ['cdsetfillhatch',['cdSetFillHatch',['../cd_8c.html#a6fb77b832a407fc880521e822780f3f0',1,'cdSetFillHatch(cdImagePtr im, int inhatch):&#160;cd.c'],['../cd_8h.html#a5ac42074b94d4906cc50f3ff6f0089a7',1,'cdSetFillHatch(cdImagePtr im, int inhatch):&#160;cd.c']]],
  ['cdsetfillstyle',['cdSetFillStyle',['../cd_8c.html#ad8a3ea3c14d1f40f2aa75c836c4feb74',1,'cdSetFillStyle(cdImagePtr im, int instyle):&#160;cd.c'],['../cd_8h.html#ace99280dbd0715eb87b76f35b7d64c99',1,'cdSetFillStyle(cdImagePtr im, int instyle):&#160;cd.c']]],
  ['cdsetlineattrib',['cdSetLineAttrib',['../cd_8c.html#a324b724322d39a8b2e35dce3961aac13',1,'cdSetLineAttrib(cdImagePtr im, int lntype, int lnwidth, int lncolor):&#160;cd.c'],['../cd_8h.html#ac048baa08ea018374e28f501012101df',1,'cdSetLineAttrib(cdImagePtr im, int lntype, int lnwidth, int lncolor):&#160;cd.c']]],
  ['cdsetlinecolor',['cdSetLineColor',['../cd_8c.html#ae22b4c2a2cbe2ef33597fd1af5b5b541',1,'cdSetLineColor(cdImagePtr im, int lncolor):&#160;cd.c'],['../cd_8h.html#a09e5d64b741fe158204688a82b27d378',1,'cdSetLineColor(cdImagePtr im, int lncolor):&#160;cd.c']]],
  ['cdsetlinetype',['cdSetLineType',['../cd_8c.html#a1d02d49eae9a515d1c249b550dd8a2fd',1,'cdSetLineType(cdImagePtr im, int lntype):&#160;cd.c'],['../cd_8h.html#aa6cad95f7f8fe665f6a84a833762627d',1,'cdSetLineType(cdImagePtr im, int lntype):&#160;cd.c']]],
  ['cdsetlinewidth',['cdSetLineWidth',['../cd_8c.html#abf35ad38e98651665ca2a575f4368104',1,'cdSetLineWidth(cdImagePtr im, int lnwidth):&#160;cd.c'],['../cd_8h.html#a93e617182b566fd8505d4709b0ae5cb5',1,'cdSetLineWidth(cdImagePtr im, int lnwidth):&#160;cd.c']]],
  ['cdsetmarkerattrib',['cdSetMarkerAttrib',['../cd_8c.html#aa34eacdedb822f61f7796b4e0ada32af',1,'cdSetMarkerAttrib(cdImagePtr im, int mtype, int msize, int mcolor):&#160;cd.c'],['../cd_8h.html#af809b6d86b708d52108789a8040067b8',1,'cdSetMarkerAttrib(cdImagePtr im, int mtype, int msize, int mcolor):&#160;cd.c']]],
  ['cdsetmarkercolor',['cdSetMarkerColor',['../cd_8c.html#ad882d76b5c208318d9a052daf77a9a3e',1,'cdSetMarkerColor(cdImagePtr im, int mcolor):&#160;cd.c'],['../cd_8h.html#a7806c2ea0bf1cbbbf003fa50d9e805f0',1,'cdSetMarkerColor(cdImagePtr im, int mcolor):&#160;cd.c']]],
  ['cdsetmarkersize',['cdSetMarkerSize',['../cd_8c.html#aea030473ca73e7b303dd7f5d46777c7a',1,'cdSetMarkerSize(cdImagePtr im, int msize):&#160;cd.c'],['../cd_8h.html#a7fffcabaaf5322a173fac0fb0f2a88cc',1,'cdSetMarkerSize(cdImagePtr im, int msize):&#160;cd.c']]],
  ['cdsetmarkertype',['cdSetMarkerType',['../cd_8c.html#a809520b320552803489ad824be1f2c41',1,'cdSetMarkerType(cdImagePtr im, int mtype):&#160;cd.c'],['../cd_8h.html#a458bf1350d453e3f583b1deab1b65df6',1,'cdSetMarkerType(cdImagePtr im, int mtype):&#160;cd.c']]],
  ['cdsetshapeedgeattrib',['cdSetShapeEdgeAttrib',['../cd_8c.html#ade772409b5fa5d9231abc680cc2210c0',1,'cdSetShapeEdgeAttrib(cdImagePtr im, int edtype, int edwidth, int edcolor, int edvis):&#160;cd.c'],['../cd_8h.html#abeaeacb5ddba7e773f8284d2211f8ecc',1,'cdSetShapeEdgeAttrib(cdImagePtr im, int edtype, int edwidth, int edcolor, int edvis):&#160;cd.c']]],
  ['cdsetshapefillattrib',['cdSetShapeFillAttrib',['../cd_8c.html#ada0138003e88dd2e11f43a62aa0b711f',1,'cdSetShapeFillAttrib(cdImagePtr im, int instyle, int incolor, int inhatch):&#160;cd.c'],['../cd_8h.html#a796a4ed8d8b8226695cccefffbcf19e3',1,'cdSetShapeFillAttrib(cdImagePtr im, int instyle, int incolor, int inhatch):&#160;cd.c']]],
  ['cdsettextattrib',['cdSetTextAttrib',['../cd_8c.html#a5ee53f2fba9fad1582758162a5d20b3e',1,'cdSetTextAttrib(cdImagePtr im, int font, int color, int height):&#160;cd.c'],['../cd_8h.html#a3390cd33b6b2c91a0d3f93f1373fe87e',1,'cdSetTextAttrib(cdImagePtr im, int font, int color, int height):&#160;cd.c']]],
  ['cdsettextcolor',['cdSetTextColor',['../cd_8c.html#add5130be4cb4333fcb0c8e1cd558495e',1,'cdSetTextColor(cdImagePtr im, int color):&#160;cd.c'],['../cd_8h.html#a04e3d8a9717c72bd86b39967e3871dfd',1,'cdSetTextColor(cdImagePtr im, int color):&#160;cd.c']]],
  ['cdsettextfont',['cdSetTextFont',['../cd_8c.html#a7c460b2ea8b662e63906c1960d9c8d06',1,'cdSetTextFont(cdImagePtr im, int font):&#160;cd.c'],['../cd_8h.html#a1bfb29aeea5b0444e63b641fa9da83f7',1,'cdSetTextFont(cdImagePtr im, int font):&#160;cd.c']]],
  ['cdsettextheight',['cdSetTextHeight',['../cd_8c.html#a3230ab361c5b1944f3adcd98c6d9fdea',1,'cdSetTextHeight(cdImagePtr im, int height):&#160;cd.c'],['../cd_8h.html#a889118904f1a23a529346139cd7b7c33',1,'cdSetTextHeight(cdImagePtr im, int height):&#160;cd.c']]],
  ['cdsettextorient',['cdSetTextOrient',['../cd_8c.html#a7cb4e7c36f57bbba3052092ed45084fc',1,'cdSetTextOrient(cdImagePtr im, int xup, int yup, int xbase, int ybase):&#160;cd.c'],['../cd_8h.html#abf12721ea082a5c19868dd56a5fa17c7',1,'cdSetTextOrient(cdImagePtr im, int xup, int yup, int xbase, int ybase):&#160;cd.c']]],
  ['cdsettextpath',['cdSetTextPath',['../cd_8c.html#af49d1a8a01745dad78cb2ce5537fd464',1,'cdSetTextPath(cdImagePtr im, int tpath):&#160;cd.c'],['../cd_8h.html#a49c986cb79f6c1eebd5a9381a3cbdccc',1,'cdSetTextPath(cdImagePtr im, int tpath):&#160;cd.c']]],
  ['cdtext',['cdText',['../cd_8c.html#ad33e1a06f1d7c60a8e48e3dd076ff561',1,'cdText(cdImagePtr im, int x, int y, const char *ts):&#160;cd.c'],['../cd_8h.html#a4475722f5324f63392a5ee1d47dd581a',1,'cdText(cdImagePtr im, int x, int y, const char *):&#160;cd.c']]],
  ['character_5farray_5fto_5fc',['character_array_to_c',['../namespaceplplot__private__utilities.html#a5835c44719fafae24e87de4327ab7013',1,'plplot_private_utilities']]],
  ['check_5fbuffer_5fsize',['check_buffer_size',['../plbuf_8c.html#a9af620a524d127e66e68dedf7f6bd89d',1,'check_buffer_size(PLStream *pls, size_t data_size):&#160;plbuf.c'],['../plmetafile_8c.html#affcee234ee73cf321c0099e83ffd8400',1,'check_buffer_size(PLmDev *dev, size_t need_size):&#160;plmetafile.c']]],
  ['check_5ffont_5fenvironment_5fvariables',['check_font_environment_variables',['../aqt_8c.html#a8b83e0b11669d22d5c6ef10ae876a6c5',1,'aqt.c']]],
  ['circle_5fbuild',['circle_build',['../delaunay_8c.html#a189383813491d98b6b00fe6299e15b91',1,'circle_build(circle *c, point *p0, point *p1, point *p2):&#160;nncommon.c'],['../nncommon_8c.html#a6778debede743a0e5e5dc210c456ab51',1,'circle_build(circle *c, point *p1, point *p2, point *p3):&#160;nncommon.c'],['../nnpi_8c.html#a189383813491d98b6b00fe6299e15b91',1,'circle_build(circle *c, point *p0, point *p1, point *p2):&#160;nncommon.c']]],
  ['circle_5fcontains',['circle_contains',['../delaunay_8c.html#a6e51a289b1d8edfa40827e1b41d667f4',1,'circle_contains(circle *c, point *p):&#160;nncommon.c'],['../nncommon_8c.html#a6e51a289b1d8edfa40827e1b41d667f4',1,'circle_contains(circle *c, point *p):&#160;nncommon.c'],['../nnpi_8c.html#a6e51a289b1d8edfa40827e1b41d667f4',1,'circle_contains(circle *c, point *p):&#160;nncommon.c']]],
  ['circulation',['circulation',['../plfill_8c.html#a6ad6543e94d58212155ed3a930842dd3',1,'plfill.c']]],
  ['ckcalloc',['ckcalloc',['../tkwin_8c.html#a45c855cdc0bd19c27be8b5cf937d43b0',1,'tkwin.c']]],
  ['cleanup_5fct',['cleanup_ct',['../plplotcPYTHON__wrap_8c.html#a567b8a6e77233b620e6e356ce926b0c5',1,'plplotcPYTHON_wrap.c']]],
  ['cleanup_5fmapform',['cleanup_mapform',['../plplotcPYTHON__wrap_8c.html#a20a1f2c307cb467884edd487c715010f',1,'plplotcPYTHON_wrap.c']]],
  ['cleanup_5fplcgrid1',['cleanup_PLcGrid1',['../plplotcPYTHON__wrap_8c.html#a50b51d3c720a3d5516de3052c316fd5b',1,'plplotcPYTHON_wrap.c']]],
  ['cleanup_5fplcgrid2',['cleanup_PLcGrid2',['../plplotcPYTHON__wrap_8c.html#a8e2cf3c60970cb7e7fc7e991a30dff14',1,'plplotcPYTHON_wrap.c']]],
  ['cleanup_5fplpointer',['cleanup_PLPointer',['../plplotcPYTHON__wrap_8c.html#a210e38636bba3af6c5db9c8db451475f',1,'plplotcPYTHON_wrap.c']]],
  ['cleanup_5fpltr',['cleanup_pltr',['../plplotcPYTHON__wrap_8c.html#a8d677910d74d3609111bb05a59ee49ec',1,'plplotcPYTHON_wrap.c']]],
  ['clear',['clear',['../classPLNamedMutex.html#ac871dfb9aa304c7b2973b6aa85500f65',1,'PLNamedMutex::clear()'],['../classplstream.html#af542aefb8cfea11f5e747e13311b5ce4',1,'plstream::clear()']]],
  ['clearbackground',['ClearBackground',['../classPlDevice.html#a691496af2bdad6325865ebf55a65ec8a',1,'PlDevice::ClearBackground()'],['../classwxPLDevice.html#adf773b89cce422a8993cff532d1468b5',1,'wxPLDevice::ClearBackground()']]],
  ['clearopts',['ClearOpts',['../classplstream.html#a3921c12c03ad654e354bbba07a6c57eb',1,'plstream']]],
  ['clipper',['Clipper',['../classClipper.html#ae06cce8f4ccf1e317fb17da05fbaf035',1,'Clipper::Clipper(wxDC *dc, const wxRect &amp;rect)'],['../classClipper.html#a90ecf4f2c049e2ce3564fa0f23aa16c5',1,'Clipper::Clipper(const Clipper &amp;)']]],
  ['clone',['clone',['../classoctave__swig__type.html#a0ff2343cfb9f5f07233661e0d6f619be',1,'octave_swig_type::clone()'],['../classoctave__swig__ref.html#a8b008bbef6f3dbcaef93a2653381f9cf',1,'octave_swig_ref::clone()'],['../classoctave__swig__packed.html#a11ad5111d10f8cee869d91bdd30ee534',1,'octave_swig_packed::clone()']]],
  ['close',['close',['../classPLMemoryMap.html#aa8bc2526af7e04aa2d31406ebf1aaedb',1,'PLMemoryMap']]],
  ['close_5fspan_5ftag',['close_span_tag',['../cairo_8c.html#a1e942016013e356b8ccc0c2b0168555f',1,'cairo.c']]],
  ['closedir',['closedir',['../dirent__msvc_8h.html#a748b9bd26c040c2ad9107c9d8c1aab42',1,'dirent_msvc.h']]],
  ['closelink',['Closelink',['../plframe_8c.html#a9368a6bdda2e156b19b2a8a5c73ae68b',1,'Closelink(Tcl_Interp *, PlFrame *, int, const char **):&#160;plframe.c'],['../plframe_8c.html#a6fe14f326cbce7eeba1f660ddf4a817b',1,'Closelink(Tcl_Interp *interp, register PlFrame *plFramePtr, int PL_UNUSED(argc), const char **PL_UNUSED(argv)):&#160;plframe.c'],['../plplotter_8c.html#a070064faa9a5d16232e31e30a23c6ea5',1,'Closelink(Tcl_Interp *, PlPlotter *, int, CONST char **):&#160;plplotter.c'],['../plplotter_8c.html#a7835b5f6be0ca9c1af26285c0b78c9b3',1,'Closelink(Tcl_Interp *interp, register PlPlotter *plPlotterPtr, int PL_UNUSED(argc), CONST char **PL_UNUSED(argv)):&#160;plplotter.c']]],
  ['closeqsas',['closeqsas',['../qsastime_8c.html#af39705af3d87fd254eddf83d6426513e',1,'closeqsas(QSASConfig **qsasconfig):&#160;qsastime.c'],['../qsastime_8h.html#ab9585a6cb19a4b761b49983f6f9b0c42',1,'closeqsas(QSASConfig **qsasconfig):&#160;qsastime.c']]],
  ['closeqtapp',['closeQtApp',['../qt_8cpp.html#aae3cd05e54105bbdf9fcd42eab9d0031',1,'qt.cpp']]],
  ['cmap0_5fpalette_5fread',['cmap0_palette_read',['../plctrl_8c.html#a4650085080e84595155f03c428439f90',1,'plctrl.c']]],
  ['cmd',['cmd',['../classplstream.html#a0aed09ebde7556077e59ecba2af1b2a8',1,'plstream::cmd()'],['../plframe_8c.html#a84242b21a699f489f5a1756ed9068d8c',1,'Cmd(Tcl_Interp *, PlFrame *, int, const char **):&#160;plframe.c'],['../plframe_8c.html#aeaf4c5a69bd1c21595c3213ade344a19',1,'Cmd(Tcl_Interp *interp, register PlFrame *plFramePtr, int argc, const char **argv):&#160;plframe.c'],['../plplotter_8c.html#a1471a95acc6c5b1b8d4809399a1eee3f',1,'Cmd(Tcl_Interp *, PlPlotter *, int, CONST char **):&#160;plplotter.c'],['../plplotter_8c.html#a8c3e973dd611da8284daeaa8025d9b2d',1,'Cmd(Tcl_Interp *interp, register PlPlotter *plPlotterPtr, int argc, CONST char **argv):&#160;plplotter.c']]],
  ['col',['col',['../classplstream.html#a814d3ed5c7a45bdc5359e252bee5b6c7',1,'plstream']]],
  ['col0',['col0',['../classplstream.html#a6cde7180bbc3ab9e10d3a4f4439bd785',1,'plstream']]],
  ['col1',['col1',['../classplstream.html#a943581cf5af193483948da880ee58f2e',1,'plstream']]],
  ['color_5fset',['color_set',['../plctrl_8c.html#ac5d19944a1c85342b0e2690698e1263e',1,'plctrl.c']]],
  ['colorbar',['colorbar',['../classplstream.html#a9364f32b836a2b176a7f05101238f501',1,'plstream']]],
  ['colormanip',['ColorManip',['../plframe_8c.html#a6b6b98b8862eabbcc25f7d3c49818a34',1,'ColorManip(Tcl_Interp *, PlFrame *, int, const char **):&#160;plframe.c'],['../plframe_8c.html#af2b731bf99058598e7b0289173db73c4',1,'ColorManip(Tcl_Interp *interp, register PlFrame *plFramePtr, int argc, const char **argv):&#160;plframe.c']]],
  ['compar',['compar',['../plfill_8c.html#a68cc8023292b0ea3f252df3b1574c25e',1,'plfill.c']]],
  ['configqsas',['configqsas',['../qsastime_8c.html#a0778c3f9a99617c42333a1e4f20c80f0',1,'configqsas(double scale, double offset1, double offset2, int ccontrol, int ifbtime_offset, int year, int month, int day, int hour, int min, double sec, QSASConfig **qsasconfig):&#160;qsastime.c'],['../qsastime_8h.html#a783595b2fcc9fd0db549f9cff28dadcf',1,'configqsas(double scale, double offset1, double offset2, int ccontrol, int ifbtime_offset, int year, int month, int day, int hour, int min, double sec, QSASConfig **qsasconfig):&#160;qsastime.c']]],
  ['configtime',['configtime',['../classplstream.html#a46ecf82c5d6c6da684f6143c650b698c',1,'plstream']]],
  ['configureplframe',['ConfigurePlFrame',['../plframe_8c.html#a322d1687eeb62ecfede9eae7dda3d266',1,'ConfigurePlFrame(Tcl_Interp *, PlFrame *, int, const char **, int):&#160;plframe.c'],['../plframe_8c.html#ab232ae7b56b246aa530c13f9657765de',1,'ConfigurePlFrame(Tcl_Interp *interp, register PlFrame *plFramePtr, int argc, const char **argv, int flags):&#160;plframe.c']]],
  ['configureplplotter',['ConfigurePlPlotter',['../plplotter_8c.html#a377a4bd65dedcd1284b515df6679b539',1,'ConfigurePlPlotter(Tcl_Interp *, PlPlotter *, int, CONST char **, int):&#160;plplotter.c'],['../plplotter_8c.html#a0911d54e934d3fca8b594d4c5d7b516f',1,'ConfigurePlPlotter(Tcl_Interp *interp, register PlPlotter *plPlotterPtr, int argc, CONST char **argv, int flags):&#160;plplotter.c']]],
  ['cont',['cont',['../classplstream.html#abebc7506ac6888b4956464b471a3df89',1,'plstream']]],
  ['cont_5fclean_5fstore',['cont_clean_store',['../plcont_8c.html#a1369d4790c599d92559808545b63f01d',1,'cont_clean_store(CONT_LEVEL *ct):&#160;plcont.c'],['../plplotP_8h.html#a1369d4790c599d92559808545b63f01d',1,'cont_clean_store(CONT_LEVEL *ct):&#160;plcont.c']]],
  ['cont_5fmv_5fstore',['cont_mv_store',['../plcont_8c.html#aa435b35f4b32c9dabd8481016986833a',1,'plcont.c']]],
  ['cont_5fnew_5fstore',['cont_new_store',['../plcont_8c.html#a80adb5ebd385ac4697cf6fcebe4006de',1,'plcont.c']]],
  ['cont_5fstore',['cont_store',['../plcont_8c.html#aca1ec0f939fa6321ae45a5855fc16e22',1,'cont_store(PLFLT_MATRIX f, PLINT nx, PLINT ny, PLINT kx, PLINT lx, PLINT ky, PLINT ly, PLFLT_VECTOR clevel, PLINT nlevel, PLTRANSFORM_callback pltr, PLPointer pltr_data, CONT_LEVEL **contour):&#160;plcont.c'],['../plplotP_8h.html#ab31ef38f5bb56843df09bf42078665c5',1,'cont_store(PLFLT_MATRIX f, PLINT nx, PLINT ny, PLINT kx, PLINT lx, PLINT ky, PLINT ly, PLFLT_VECTOR clevel, PLINT nlevel, void(*pltr)(PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer), PLPointer pltr_data, CONT_LEVEL **contour):&#160;plplotP.h']]],
  ['cont_5fxy_5fstore',['cont_xy_store',['../plcont_8c.html#a52a71436e6b8dfbb16d2b29e48791b0f',1,'plcont.c']]],
  ['contourable_5fdata',['Contourable_Data',['../classContourable__Data.html#a8d994870c40b148f0afa2babfbd6253f',1,'Contourable_Data']]],
  ['contourable_5fdata_5fevaluator',['Contourable_Data_evaluator',['../plstream_8cc.html#aea4325c629efa6ce4a3ac25d113cb787',1,'Contourable_Data_evaluator(PLINT i, PLINT j, PLPointer p):&#160;plstream.cc'],['../plstream_8h.html#a1951493a902c37f85119c412978e70e8',1,'Contourable_Data_evaluator(PLINT i, PLINT j, PLPointer p):&#160;plstream.cc']]],
  ['convert_5farray',['convert_array',['../namespaceplplot.html#aba0627d998c5a1e8fe7e417bbb69ce7b',1,'plplot']]],
  ['convert_5fto_5fstr',['convert_to_str',['../classoctave__swig__type.html#a04d8c1673e160bb7a9d308b830cbed5c',1,'octave_swig_type::convert_to_str()'],['../classoctave__swig__ref.html#a9d3c41a68f9b2f9cdede33926bc98062',1,'octave_swig_ref::convert_to_str()']]],
  ['convert_5fto_5fstr_5finternal',['convert_to_str_internal',['../classoctave__swig__type.html#af71c0af2572b864f4352afff53dd95f6',1,'octave_swig_type::convert_to_str_internal()'],['../classoctave__swig__ref.html#adc55a56010ed42f018336736c6bb7106',1,'octave_swig_ref::convert_to_str_internal()']]],
  ['coord_5fxform_5fevaluator',['Coord_Xform_evaluator',['../plstream_8cc.html#a3a348ecf248ba26de11828eeb6552be3',1,'Coord_Xform_evaluator(PLFLT ox, PLFLT oy, PLFLT *nx, PLFLT *ny, PLPointer p):&#160;plstream.cc'],['../plstream_8h.html#a527d38976b14dad3b413fc2dd7a884df',1,'Coord_Xform_evaluator(PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer):&#160;plstream.cc']]],
  ['copy',['copy',['../classoctave__swig__packed.html#ae2ef561e6dfd97f09dce929b6bfcc794',1,'octave_swig_packed']]],
  ['copystring2f',['copystring2f',['../namespaceplplot__private__utilities.html#ab9d16dd4461b878edd9990eb4d499f4a',1,'plplot_private_utilities']]],
  ['cpp_5fptr',['cpp_ptr',['../structoctave__swig__type_1_1cpp__ptr.html#a675a130f155afd17c25c60dddfd7162f',1,'octave_swig_type::cpp_ptr']]],
  ['cpstrm',['cpstrm',['../classplstream.html#ab24f6d2d81f77b70cc8c2ca34c38973c',1,'plstream']]],
  ['create',['Create',['../classwxPLplotstream.html#af248a283d04a83fbb83661a7c0a4b61e',1,'wxPLplotstream::Create()'],['../classPLMemoryMap.html#aad0d3a12211797e242f25666b99f2066',1,'PLMemoryMap::create()'],['../classPLNamedMutex.html#a7151127622175d2731ecbb49c453c9ec',1,'PLNamedMutex::create()']]],
  ['create_5fstring',['create_string',['../aqt_8c.html#a56843721c7bb07273acc80ccf8eadeb6',1,'aqt.c']]],
  ['createfont',['createFont',['../classFont.html#a5f9dd24c29cb14f8083cc47e803a2106',1,'Font']]],
  ['createrband',['CreateRband',['../plframe_8c.html#a497652ae8700c5640d1d59d274eec3a6',1,'CreateRband(PlFrame *):&#160;plframe.c'],['../plplotter_8c.html#a9ec3611762c264aecbde987d78ad3925',1,'CreateRband(PlPlotter *):&#160;plplotter.c']]],
  ['createxhairs',['CreateXhairs',['../plframe_8c.html#a2e247e4f485d95ac1a057dd25d53eb0c',1,'CreateXhairs(PlFrame *):&#160;plframe.c'],['../plplotter_8c.html#aad3de4b143564dc09823914c0b966c01',1,'CreateXhairs(PlPlotter *):&#160;plplotter.c']]],
  ['csa_5faddpoints',['csa_addpoints',['../csa_8c.html#a36cfd23c72afcac71adb67a201f34b60',1,'csa_addpoints(csa *a, int n, point points[]):&#160;csa.c'],['../csa_8h.html#ae15af625f487d309b340a10fc1dfcc77',1,'csa_addpoints(csa *a, int n, point points[]):&#160;csa.c']]],
  ['csa_5fapproximate_5fpoint',['csa_approximate_point',['../csa_8c.html#ab8c6bb0fc6bfa6c29d120ea6a8873747',1,'csa_approximate_point(csa *a, point *p):&#160;csa.c'],['../csa_8h.html#a5e6dfc31c946e46a29741df8f28a1de1',1,'csa_approximate_point(csa *a, point *p):&#160;csa.c']]],
  ['csa_5fapproximate_5fpoints',['csa_approximate_points',['../csa_8c.html#a8e926911cc6cac5677d39ac16c441a7b',1,'csa_approximate_points(csa *a, int n, point *points):&#160;csa.c'],['../csa_8h.html#a28cc37275555f5595c745421ab5d73f3',1,'csa_approximate_points(csa *a, int n, point *points):&#160;csa.c']]],
  ['csa_5fattachpoints',['csa_attachpoints',['../csa_8c.html#a0142ff386966a021fe162c6c4d19423a',1,'csa.c']]],
  ['csa_5fcalculatespline',['csa_calculatespline',['../csa_8c.html#a8d1051e0f4afb03e5db6da672f547cd6',1,'csa_calculatespline(csa *a):&#160;csa.c'],['../csa_8h.html#a0c457306a664d4046fa2d74ea772f914',1,'csa_calculatespline(csa *a):&#160;csa.c']]],
  ['csa_5fcreate',['csa_create',['../csa_8c.html#abf65e99ebde825d362d9889ecaac3f9f',1,'csa_create():&#160;csa.c'],['../csa_8h.html#a252b310188569b8a7b054bd8d89e7ce5',1,'csa_create(void):&#160;csa.c']]],
  ['csa_5fdestroy',['csa_destroy',['../csa_8c.html#ac9e4d82e7baf8341d87ab02f1a7705b3',1,'csa_destroy(csa *a):&#160;csa.c'],['../csa_8h.html#a9e11de85ae2b18405bc0379f15123419',1,'csa_destroy(csa *a):&#160;csa.c']]],
  ['csa_5ffindprimarycoeffs',['csa_findprimarycoeffs',['../csa_8c.html#a6f0a12f18353b74ace54c1bcae10aa53',1,'csa.c']]],
  ['csa_5ffindsecondarycoeffs',['csa_findsecondarycoeffs',['../csa_8c.html#a2bf110d9a6626f4a7da960b614533aa0',1,'csa.c']]],
  ['csa_5fquit',['csa_quit',['../csa_8c.html#aef3572eab2c081bfcd86485bc3447cca',1,'csa.c']]],
  ['csa_5fsethascoeffsflag',['csa_sethascoeffsflag',['../csa_8c.html#a129e31a15637f2cc6fc63d3b9bdc9dcd',1,'csa.c']]],
  ['csa_5fsetk',['csa_setk',['../csa_8c.html#a01af2f9fb62f7ac9092f07e706c948e9',1,'csa_setk(csa *a, int k):&#160;csa.c'],['../csa_8h.html#a3729d13a1bb93bd163557f680fe0ec9a',1,'csa_setk(csa *a, int k):&#160;csa.c']]],
  ['csa_5fsetnpmax',['csa_setnpmax',['../csa_8c.html#aedb0411f23f654c2b6184ac0b64a51d5',1,'csa_setnpmax(csa *a, int npmax):&#160;csa.c'],['../csa_8h.html#abf60efc0877931004c510184a8bff6f3',1,'csa_setnpmax(csa *a, int npmax):&#160;csa.c']]],
  ['csa_5fsetnpmin',['csa_setnpmin',['../csa_8c.html#a23d7716d7b29bed9a7d8e552759bbba8',1,'csa_setnpmin(csa *a, int npmin):&#160;csa.c'],['../csa_8h.html#a6c65bd87724f7159773929693293e222',1,'csa_setnpmin(csa *a, int npmin):&#160;csa.c']]],
  ['csa_5fsetnppc',['csa_setnppc',['../csa_8c.html#acf0c3c7a2beb6dd52b5906fda6ab41d9',1,'csa.c']]],
  ['csa_5fsetnpps',['csa_setnpps',['../csa_8h.html#a953d5b90faeed5bb886f8e752b48f14a',1,'csa.h']]],
  ['csa_5fsetprimaryflag',['csa_setprimaryflag',['../csa_8c.html#aacd2b5e8588e39c8f6409814ff2458b1',1,'csa.c']]],
  ['csa_5fsquarize',['csa_squarize',['../csa_8c.html#ab25b13bfe1c350337e9ab676ec91ed40',1,'csa.c']]],
  ['ct_5foctave',['ct_octave',['../plplot__octaveOCTAVE__wrap_8cxx.html#ae6d2a47dc41456407a6f5ae3cfceeaaa',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['ctime',['ctime',['../classplstream.html#a60956f9ea224e1007f85ef218166fc4f',1,'plstream']]],
  ['ctimeqsas',['ctimeqsas',['../qsastime_8c.html#ad78b3024de5e62756d3a3da809dab6d6',1,'ctimeqsas(int year, int month, int day, int hour, int min, double sec, double *ctime, QSASConfig *qsasconfig):&#160;qsastime.c'],['../qsastime_8h.html#a9f2155f0cb55f03d0e18112989ce1099',1,'ctimeqsas(int year, int month, int day, int hour, int min, double sec, double *ctime, QSASConfig *qsasconfig):&#160;qsastime.c']]],
  ['cw',['cw',['../delaunay_8c.html#ae897ab66a2f4448bf28f6e45210a9a7f',1,'delaunay.c']]],
  ['cxx_5fpltr2',['cxx_pltr2',['../classcxx__pltr2.html#ab381fa04aadbde5e43c1a34dd2af7415',1,'cxx_pltr2']]]
];
